@@ -30,28 +30,30 @@ public interface CommonOptions {
                     .noDefaultValue()
                     .withDescription("Name of the SPI plugin class.");
 
-    Option<String> RESULT_TABLE_NAME =
-            Options.key("result_table_name")
+    Option<String> PLUGIN_OUTPUT =
+            Options.key("plugin_output")
                     .stringType()
                     .noDefaultValue()
+                    .withFallbackKeys("result_table_name")
                     .withDescription(
-                            "When result_table_name is not specified, "
+                            "When plugin_output is not specified, "
                                     + "the data processed by this plugin will not be registered as a data set (dataStream/dataset) "
                                     + "that can be directly accessed by other plugins, or called a temporary table (table)"
-                                    + "When result_table_name is specified, "
+                                    + "When plugin_output is specified, "
                                     + "the data processed by this plugin will be registered as a data set (dataStream/dataset) "
                                     + "that can be directly accessed by other plugins, or called a temporary table (table) . "
                                     + "The data set (dataStream/dataset) registered here can be directly accessed by other plugins "
-                                    + "by specifying source_table_name .");
+                                    + "by specifying plugin_input .");
 
-    Option<List<String>> SOURCE_TABLE_NAME =
-            Options.key("source_table_name")
+    Option<List<String>> PLUGIN_INPUT =
+            Options.key("plugin_input")
                     .listType()
                     .noDefaultValue()
+                    .withFallbackKeys("source_table_name")
                     .withDescription(
-                            "When source_table_name is not specified, "
+                            "When plugin_input is not specified, "
                                     + "the current plug-in processes the data set dataset output by the previous plugin in the configuration file. "
-                                    + "When source_table_name is specified, the current plug-in is processing the data set corresponding to this parameter.");
+                                    + "When plugin_input is specified, the current plug-in is processing the data set corresponding to this parameter.");
 
     Option<Integer> PARALLELISM =
             Options.key("parallelism")
