@@ -25,14 +25,19 @@ import org.apache.seatunnel.api.sink.SinkAggregatedCommitter;
 import org.apache.seatunnel.api.sink.SinkCommitter;
 import org.apache.seatunnel.api.sink.SinkCommonOptions;
 import org.apache.seatunnel.api.sink.SinkWriter;
+import org.apache.seatunnel.api.sink.SupportSchemaEvolutionSink;
+import org.apache.seatunnel.api.table.catalog.CatalogTable;
 import org.apache.seatunnel.api.table.catalog.TablePath;
 import org.apache.seatunnel.api.table.factory.MultiTableFactoryContext;
+import org.apache.seatunnel.api.table.schema.SchemaChangeType;
 import org.apache.seatunnel.api.table.type.SeaTunnelRow;
 
 import lombok.Getter;
 
 import java.io.IOException;
+import java.util.ArrayList;
 import java.util.Collection;
+import java.util.Collections;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
@@ -42,10 +47,11 @@ import java.util.stream.Collectors;
 
 public class MultiTableSink
         implements SeaTunnelSink<
-                SeaTunnelRow,
-                MultiTableState,
-                MultiTableCommitInfo,
-                MultiTableAggregatedCommitInfo> {
+                        SeaTunnelRow,
+                        MultiTableState,
+                        MultiTableCommitInfo,
+                        MultiTableAggregatedCommitInfo>,
+                SupportSchemaEvolutionSink {
 
     @Getter private final Map<String, SeaTunnelSink> sinks;
     private final int replicaNum;
@@ -157,7 +163,18 @@ public class MultiTableSink
     }
 
     public List<TablePath> getSinkTables() {
-        return sinks.keySet().stream().map(TablePath::of).collect(Collectors.toList());
+
+        List<TablePath> tablePaths = new ArrayList<>();
+        List<SeaTunnelSink> values = new ArrayList<>(sinks.values());
+        for (int i = 0; i < values.size(); i++) {
+            if (values.get(i).getWriteCatalogTable().isPresent()) {
+                tablePaths.add(
+                        ((CatalogTable) values.get(i).getWriteCatalogTable().get()).getTablePath());
+            } else {
+                tablePaths.add(TablePath.of(sinks.keySet().toArray(new String[0])[i]));
+            }
+        }
+        return tablePaths;
     }
 
     @Override
@@ -170,4 +187,18 @@ public class MultiTableSink
     public void setJobContext(JobContext jobContext) {
         sinks.values().forEach(sink -> sink.setJobContext(jobContext));
     }
+
+    @Override
+    public Optional<CatalogTable> getWriteCatalogTable() {
+        return SeaTunnelSink.super.getWriteCatalogTable();
+    }
+
+    @Override
+    public List<SchemaChangeType> supports() {
+        SeaTunnelSink firstSink = sinks.entrySet().iterator().next().getValue();
+        if (firstSink instanceof SupportSchemaEvolutionSink) {
+            return ((SupportSchemaEvolutionSink) firstSink).supports();
+        }
+        return Collections.emptyList();
+    }
 }
