@@ -79,6 +79,8 @@ public class SeaTunnelDataTypeConvertorUtil {
                 return LocalTimeType.LOCAL_TIME_TYPE;
             case TIMESTAMP:
                 return LocalTimeType.LOCAL_DATE_TIME_TYPE;
+            case TIMESTAMP_TZ:
+                return LocalTimeType.OFFSET_DATE_TIME_TYPE;
             case MAP:
                 return parseMapType(field, columnType);
             case BINARY_VECTOR:
