@@ -20,6 +20,7 @@ package org.apache.seatunnel.api.table.type;
 import java.io.Serializable;
 import java.nio.ByteBuffer;
 import java.util.Arrays;
+import java.util.HashMap;
 import java.util.Map;
 import java.util.Objects;
 
@@ -33,6 +34,8 @@ public final class SeaTunnelRow implements Serializable {
     /** The array to store the actual internal format values. */
     private final Object[] fields;
 
+    private Map<String, Object> options;
+
     private volatile int size;
 
     public SeaTunnelRow(int arity) {
@@ -55,6 +58,10 @@ public final class SeaTunnelRow implements Serializable {
         this.rowKind = rowKind;
     }
 
+    public void setOptions(Map<String, Object> options) {
+        this.options = options;
+    }
+
     public int getArity() {
         return fields.length;
     }
@@ -67,6 +74,13 @@ public final class SeaTunnelRow implements Serializable {
         return this.rowKind;
     }
 
+    public Map<String, Object> getOptions() {
+        if (options == null) {
+            options = new HashMap<>();
+        }
+        return options;
+    }
+
     public Object[] getFields() {
         return fields;
     }
@@ -141,6 +155,7 @@ public final class SeaTunnelRow implements Serializable {
             case TIME:
                 return 12;
             case TIMESTAMP:
+            case TIMESTAMP_TZ:
                 return 48;
             case FLOAT_VECTOR:
             case FLOAT16_VECTOR:
@@ -163,6 +178,7 @@ public final class SeaTunnelRow implements Serializable {
                         case TIME:
                             return ((Object[]) v).length * 12;
                         case TIMESTAMP:
+                        case TIMESTAMP_TZ:
                             return ((Object[]) v).length * 48;
                         default:
                             throw new UnsupportedOperationException(
@@ -271,6 +287,7 @@ public final class SeaTunnelRow implements Serializable {
             case "LocalTime":
                 return 12;
             case "LocalDateTime":
+            case "OffsetDateTime":
                 return 48;
             case "String[]":
                 return getBytesForArray(v, BasicType.STRING_TYPE);
