@@ -17,21 +17,23 @@
 
 package org.apache.seatunnel.connectors.cdc.debezium.row;
 
+import org.apache.seatunnel.api.event.EventType;
 import org.apache.seatunnel.api.source.Collector;
+import org.apache.seatunnel.api.table.catalog.CatalogTable;
 import org.apache.seatunnel.api.table.catalog.TablePath;
-import org.apache.seatunnel.api.table.event.SchemaChangeEvent;
-import org.apache.seatunnel.api.table.event.handler.DataTypeChangeEventDispatcher;
-import org.apache.seatunnel.api.table.event.handler.DataTypeChangeEventHandler;
-import org.apache.seatunnel.api.table.type.MultipleRowType;
+import org.apache.seatunnel.api.table.catalog.TableSchema;
+import org.apache.seatunnel.api.table.schema.event.AlterTableColumnEvent;
+import org.apache.seatunnel.api.table.schema.event.AlterTableColumnsEvent;
+import org.apache.seatunnel.api.table.schema.event.SchemaChangeEvent;
+import org.apache.seatunnel.api.table.schema.handler.TableSchemaChangeEventDispatcher;
+import org.apache.seatunnel.api.table.schema.handler.TableSchemaChangeEventHandler;
+import org.apache.seatunnel.api.table.type.MetadataUtil;
 import org.apache.seatunnel.api.table.type.RowKind;
-import org.apache.seatunnel.api.table.type.SeaTunnelDataType;
 import org.apache.seatunnel.api.table.type.SeaTunnelRow;
-import org.apache.seatunnel.api.table.type.SeaTunnelRowType;
-import org.apache.seatunnel.api.table.type.SqlType;
 import org.apache.seatunnel.connectors.cdc.base.schema.SchemaChangeResolver;
 import org.apache.seatunnel.connectors.cdc.base.utils.SourceRecordUtils;
+import org.apache.seatunnel.connectors.cdc.debezium.AbstractDebeziumDeserializationSchema;
 import org.apache.seatunnel.connectors.cdc.debezium.DebeziumDeserializationConverterFactory;
-import org.apache.seatunnel.connectors.cdc.debezium.DebeziumDeserializationSchema;
 import org.apache.seatunnel.connectors.cdc.debezium.MetadataConverter;
 
 import org.apache.kafka.connect.data.Schema;
@@ -39,6 +41,7 @@ import org.apache.kafka.connect.data.Struct;
 import org.apache.kafka.connect.source.SourceRecord;
 
 import io.debezium.data.Envelope;
+import io.debezium.relational.TableId;
 import lombok.AccessLevel;
 import lombok.NoArgsConstructor;
 import lombok.Setter;
@@ -46,19 +49,22 @@ import lombok.experimental.Accessors;
 import lombok.extern.slf4j.Slf4j;
 
 import java.time.ZoneId;
+import java.util.ArrayList;
 import java.util.HashMap;
+import java.util.List;
 import java.util.Map;
+import java.util.stream.Collectors;
 
-import static com.google.common.base.Preconditions.checkNotNull;
 import static org.apache.seatunnel.connectors.cdc.base.source.split.wartermark.WatermarkEvent.isSchemaChangeAfterWatermarkEvent;
 import static org.apache.seatunnel.connectors.cdc.base.source.split.wartermark.WatermarkEvent.isSchemaChangeBeforeWatermarkEvent;
 import static org.apache.seatunnel.connectors.cdc.base.utils.SourceRecordUtils.isDataChangeRecord;
 import static org.apache.seatunnel.connectors.cdc.base.utils.SourceRecordUtils.isSchemaChangeEvent;
+import static org.apache.seatunnel.shade.com.google.common.base.Preconditions.checkNotNull;
 
 /** Deserialization schema from Debezium object to {@link SeaTunnelRow}. */
 @Slf4j
 public final class SeaTunnelRowDebeziumDeserializeSchema
-        implements DebeziumDeserializationSchema<SeaTunnelRow> {
+        extends AbstractDebeziumDeserializationSchema<SeaTunnelRow> {
     private static final long serialVersionUID = 1L;
     private static final String DEFAULT_TABLE_NAME_KEY = null;
 
@@ -66,34 +72,34 @@ public final class SeaTunnelRowDebeziumDeserializeSchema
     private final ZoneId serverTimeZone;
     private final DebeziumDeserializationConverterFactory userDefinedConverterFactory;
     private final SchemaChangeResolver schemaChangeResolver;
-    private final DataTypeChangeEventHandler dataTypeChangeEventHandler;
-    private SeaTunnelDataType<SeaTunnelRow> resultTypeInfo;
+    private final TableSchemaChangeEventHandler tableSchemaChangeHandler;
+    private List<CatalogTable> tables;
     private Map<String, SeaTunnelRowDebeziumDeserializationConverters> tableRowConverters;
 
     SeaTunnelRowDebeziumDeserializeSchema(
-            SeaTunnelDataType<SeaTunnelRow> physicalDataType,
             MetadataConverter[] metadataConverters,
-            SeaTunnelDataType<SeaTunnelRow> resultType,
+            List<CatalogTable> tables,
             ZoneId serverTimeZone,
             DebeziumDeserializationConverterFactory userDefinedConverterFactory,
-            SchemaChangeResolver schemaChangeResolver) {
+            SchemaChangeResolver schemaChangeResolver,
+            Map<TableId, Struct> tableIdTableChangeMap) {
+        super(tableIdTableChangeMap);
         this.metadataConverters = metadataConverters;
         this.serverTimeZone = serverTimeZone;
         this.userDefinedConverterFactory = userDefinedConverterFactory;
-        this.resultTypeInfo = checkNotNull(resultType);
+        this.tables = checkNotNull(tables);
         this.schemaChangeResolver = schemaChangeResolver;
-        this.dataTypeChangeEventHandler = new DataTypeChangeEventDispatcher();
+        this.tableSchemaChangeHandler = new TableSchemaChangeEventDispatcher();
         this.tableRowConverters =
                 createTableRowConverters(
-                        resultType,
-                        metadataConverters,
-                        serverTimeZone,
-                        userDefinedConverterFactory);
+                        tables, metadataConverters, serverTimeZone, userDefinedConverterFactory);
     }
 
     @Override
     public void deserialize(SourceRecord record, Collector<SeaTunnelRow> collector)
             throws Exception {
+        super.deserialize(record, collector);
+
         if (isSchemaChangeBeforeWatermarkEvent(record)) {
             collector.markSchemaChangeBeforeCheckpoint();
             return;
@@ -117,42 +123,81 @@ public final class SeaTunnelRowDebeziumDeserializeSchema
 
     private void deserializeSchemaChangeRecord(
             SourceRecord record, Collector<SeaTunnelRow> collector) {
-        SchemaChangeEvent schemaChangeEvent = schemaChangeResolver.resolve(record, resultTypeInfo);
+        SchemaChangeEvent schemaChangeEvent = null;
+        try {
+            if (schemaChangeResolver != null) {
+                schemaChangeEvent = schemaChangeResolver.resolve(record, null);
+            }
+        } catch (Exception e) {
+            log.warn("Failed to resolve schemaChangeEvent, just skip.", e);
+            return;
+        }
         if (schemaChangeEvent == null) {
             log.warn("Unsupported resolve schemaChangeEvent {}, just skip.", record);
             return;
         }
-        if (resultTypeInfo instanceof MultipleRowType) {
-            Map<String, SeaTunnelRowType> newRowTypeMap = new HashMap<>();
-            for (Map.Entry<String, SeaTunnelRowType> entry : (MultipleRowType) resultTypeInfo) {
-                if (!entry.getKey().equals(schemaChangeEvent.tablePath().toString())) {
-                    newRowTypeMap.put(entry.getKey(), entry.getValue());
-                    continue;
-                }
-
-                log.debug("Table[{}] datatype change before: {}", entry.getKey(), entry.getValue());
-                SeaTunnelRowType newRowType =
-                        dataTypeChangeEventHandler.reset(entry.getValue()).apply(schemaChangeEvent);
-                newRowTypeMap.put(entry.getKey(), newRowType);
-                log.debug("Table[{}] datatype change after: {}", entry.getKey(), newRowType);
+        boolean tableExist = false;
+        for (int i = 0; i < tables.size(); i++) {
+            CatalogTable changeBefore = tables.get(i);
+            if (!schemaChangeEvent.tablePath().equals(changeBefore.getTablePath())) {
+                continue;
             }
-            resultTypeInfo = new MultipleRowType(newRowTypeMap);
-        } else {
-            log.debug("Table datatype change before: {}", resultTypeInfo);
-            resultTypeInfo =
-                    dataTypeChangeEventHandler
-                            .reset((SeaTunnelRowType) resultTypeInfo)
-                            .apply(schemaChangeEvent);
-            log.debug("table datatype change after: {}", resultTypeInfo);
-        }
 
+            tableExist = true;
+            log.debug(
+                    "Table[{}] change before: {}",
+                    schemaChangeEvent.tablePath(),
+                    changeBefore.getTableSchema());
+
+            CatalogTable changeAfter = null;
+            if (EventType.SCHEMA_CHANGE_UPDATE_COLUMNS.equals(schemaChangeEvent.getEventType())) {
+                AlterTableColumnsEvent alterTableColumnsEvent =
+                        (AlterTableColumnsEvent) schemaChangeEvent;
+                for (AlterTableColumnEvent event : alterTableColumnsEvent.getEvents()) {
+                    TableSchema changeAfterSchema =
+                            tableSchemaChangeHandler
+                                    .reset(changeBefore.getTableSchema())
+                                    .apply(event);
+                    changeAfter =
+                            CatalogTable.of(
+                                    changeBefore.getTableId(),
+                                    changeAfterSchema,
+                                    changeBefore.getOptions(),
+                                    changeBefore.getPartitionKeys(),
+                                    changeBefore.getComment());
+                    event.setChangeAfter(changeAfter);
+
+                    changeBefore = changeAfter;
+                }
+            } else {
+                TableSchema changeAfterSchema =
+                        tableSchemaChangeHandler
+                                .reset(changeBefore.getTableSchema())
+                                .apply(schemaChangeEvent);
+                changeAfter =
+                        CatalogTable.of(
+                                changeBefore.getTableId(),
+                                changeAfterSchema,
+                                changeBefore.getOptions(),
+                                changeBefore.getPartitionKeys(),
+                                changeBefore.getComment());
+            }
+            tables.set(i, changeAfter);
+            schemaChangeEvent.setChangeAfter(changeAfter);
+            log.debug(
+                    "Table[{}] change after: {}",
+                    schemaChangeEvent.tablePath(),
+                    changeAfter.getTableSchema());
+            break;
+        }
+        if (!tableExist) {
+            log.error(
+                    "Not found table {}, skip schema change event {}",
+                    schemaChangeEvent.tablePath());
+        }
         tableRowConverters =
                 createTableRowConverters(
-                        resultTypeInfo,
-                        metadataConverters,
-                        serverTimeZone,
-                        userDefinedConverterFactory);
-
+                        tables, metadataConverters, serverTimeZone, userDefinedConverterFactory);
         collector.collect(schemaChangeEvent);
     }
 
@@ -164,7 +209,7 @@ public final class SeaTunnelRowDebeziumDeserializeSchema
         TablePath tablePath = SourceRecordUtils.getTablePath(record);
         String tableId = tablePath.toString();
         SeaTunnelRowDebeziumDeserializationConverters converters;
-        if (resultTypeInfo instanceof MultipleRowType) {
+        if (tables.size() > 1) {
             converters = tableRowConverters.get(tableId);
             if (converters == null) {
                 log.debug("Ignore newly added table {}", tableId);
@@ -173,26 +218,39 @@ public final class SeaTunnelRowDebeziumDeserializeSchema
         } else {
             converters = tableRowConverters.get(DEFAULT_TABLE_NAME_KEY);
         }
-
+        Long fetchTimestamp = SourceRecordUtils.getFetchTimestamp(record);
+        Long messageTimestamp = SourceRecordUtils.getMessageTimestamp(record);
+        long delay = -1L;
+        if (fetchTimestamp != null && messageTimestamp != null) {
+            delay = fetchTimestamp - messageTimestamp;
+        }
         if (operation == Envelope.Operation.CREATE || operation == Envelope.Operation.READ) {
             SeaTunnelRow insert = extractAfterRow(converters, record, messageStruct, valueSchema);
             insert.setRowKind(RowKind.INSERT);
             insert.setTableId(tableId);
+            MetadataUtil.setDelay(insert, delay);
+            MetadataUtil.setEventTime(insert, fetchTimestamp);
             collector.collect(insert);
         } else if (operation == Envelope.Operation.DELETE) {
             SeaTunnelRow delete = extractBeforeRow(converters, record, messageStruct, valueSchema);
             delete.setRowKind(RowKind.DELETE);
             delete.setTableId(tableId);
+            MetadataUtil.setDelay(delete, delay);
+            MetadataUtil.setEventTime(delete, fetchTimestamp);
             collector.collect(delete);
         } else if (operation == Envelope.Operation.UPDATE) {
             SeaTunnelRow before = extractBeforeRow(converters, record, messageStruct, valueSchema);
             before.setRowKind(RowKind.UPDATE_BEFORE);
             before.setTableId(tableId);
+            MetadataUtil.setDelay(before, delay);
+            MetadataUtil.setEventTime(before, fetchTimestamp);
             collector.collect(before);
 
             SeaTunnelRow after = extractAfterRow(converters, record, messageStruct, valueSchema);
             after.setRowKind(RowKind.UPDATE_AFTER);
             after.setTableId(tableId);
+            MetadataUtil.setDelay(after, delay);
+            MetadataUtil.setEventTime(after, fetchTimestamp);
             collector.collect(after);
         } else {
             log.warn("Received {} operation, skip", operation);
@@ -224,8 +282,8 @@ public final class SeaTunnelRowDebeziumDeserializeSchema
     }
 
     @Override
-    public SeaTunnelDataType<SeaTunnelRow> getProducedType() {
-        return resultTypeInfo;
+    public List<CatalogTable> getProducedType() {
+        return tables;
     }
 
     @Override
@@ -234,77 +292,61 @@ public final class SeaTunnelRowDebeziumDeserializeSchema
     }
 
     @Override
-    public void restoreCheckpointProducedType(SeaTunnelDataType<SeaTunnelRow> checkpointDataType) {
+    public void restoreCheckpointProducedType(List<CatalogTable> checkpointDataType) {
         // If checkpointDataType is null, it indicates that DDL changes are not supported.
         // Therefore, we need to use the latest table structure to ensure that data from newly added
         // columns can be parsed correctly.
         if (schemaChangeResolver == null) {
             return;
         }
-        if (SqlType.ROW.equals(checkpointDataType.getSqlType())
-                && SqlType.MULTIPLE_ROW.equals(resultTypeInfo.getSqlType())) {
-            // TODO: Older versions may have this issue
-            log.warn(
-                    "Skip incompatible restore type. produced type: {}, checkpoint type: {}",
-                    resultTypeInfo,
-                    checkpointDataType);
-            return;
-        }
-        if (checkpointDataType instanceof MultipleRowType) {
-            MultipleRowType latestDataType = (MultipleRowType) resultTypeInfo;
-            Map<String, SeaTunnelRowType> newRowTypeMap = new HashMap<>();
-            for (Map.Entry<String, SeaTunnelRowType> entry : latestDataType) {
-                newRowTypeMap.put(entry.getKey(), entry.getValue());
-            }
-            for (Map.Entry<String, SeaTunnelRowType> entry : (MultipleRowType) checkpointDataType) {
-                SeaTunnelRowType oldDataType = latestDataType.getRowType(entry.getKey());
-                if (oldDataType == null) {
-                    log.info("Ignore restore table[{}] datatype has been deleted.", entry.getKey());
-                    continue;
-                }
 
-                log.info("Table[{}] datatype restore before: {}", entry.getKey(), oldDataType);
-                newRowTypeMap.put(entry.getKey(), entry.getValue());
-                log.info("Table[{}] datatype restore after: {}", entry.getKey(), entry.getValue());
+        Map<TablePath, CatalogTable> latestTableMap =
+                this.tables.stream().collect(Collectors.toMap(CatalogTable::getTablePath, t -> t));
+        Map<TablePath, CatalogTable> restoreTableMap =
+                checkpointDataType.stream()
+                        .collect(Collectors.toMap(CatalogTable::getTablePath, t -> t));
+        for (TablePath tablePath : restoreTableMap.keySet()) {
+            CatalogTable latestTable = latestTableMap.get(tablePath);
+            CatalogTable restoreTable = restoreTableMap.get(tablePath);
+            if (latestTable == null) {
+                log.info("Ignore restore table[{}] has been deleted.", tablePath);
+                continue;
             }
-            resultTypeInfo = new MultipleRowType(newRowTypeMap);
-        } else {
-            log.info("Table datatype restore before: {}", resultTypeInfo);
-            resultTypeInfo = checkpointDataType;
-            log.info("Table datatype restore after: {}", checkpointDataType);
+
+            log.info("Table[{}] restore before: {}", tablePath, latestTable.getSeaTunnelRowType());
+            latestTableMap.put(tablePath, restoreTable);
+            log.info("Table[{}] restore after: {}", tablePath, restoreTable.getSeaTunnelRowType());
         }
-        tableRowConverters =
+        this.tables = new ArrayList<>(latestTableMap.values());
+        this.tableRowConverters =
                 createTableRowConverters(
-                        resultTypeInfo,
-                        metadataConverters,
-                        serverTimeZone,
-                        userDefinedConverterFactory);
+                        tables, metadataConverters, serverTimeZone, userDefinedConverterFactory);
     }
 
     private static Map<String, SeaTunnelRowDebeziumDeserializationConverters>
             createTableRowConverters(
-                    SeaTunnelDataType<SeaTunnelRow> inputDataType,
+                    List<CatalogTable> tables,
                     MetadataConverter[] metadataConverters,
                     ZoneId serverTimeZone,
                     DebeziumDeserializationConverterFactory userDefinedConverterFactory) {
         Map<String, SeaTunnelRowDebeziumDeserializationConverters> tableRowConverters =
                 new HashMap<>();
-        if (inputDataType instanceof MultipleRowType) {
-            for (Map.Entry<String, SeaTunnelRowType> item : (MultipleRowType) inputDataType) {
+        if (tables.size() > 1) {
+            for (CatalogTable table : tables) {
                 SeaTunnelRowDebeziumDeserializationConverters itemRowConverter =
                         new SeaTunnelRowDebeziumDeserializationConverters(
-                                item.getValue(),
+                                table.getSeaTunnelRowType(),
                                 metadataConverters,
                                 serverTimeZone,
                                 userDefinedConverterFactory);
-                tableRowConverters.put(item.getKey(), itemRowConverter);
+                tableRowConverters.put(table.getTablePath().toString(), itemRowConverter);
             }
             return tableRowConverters;
         }
 
         SeaTunnelRowDebeziumDeserializationConverters tableRowConverter =
                 new SeaTunnelRowDebeziumDeserializationConverters(
-                        (SeaTunnelRowType) inputDataType,
+                        tables.get(0).getSeaTunnelRowType(),
                         metadataConverters,
                         serverTimeZone,
                         userDefinedConverterFactory);
@@ -320,22 +362,22 @@ public final class SeaTunnelRowDebeziumDeserializeSchema
     @Accessors(chain = true)
     @NoArgsConstructor(access = AccessLevel.PRIVATE)
     public static class Builder {
-        private SeaTunnelDataType<SeaTunnelRow> physicalRowType;
-        private SeaTunnelDataType<SeaTunnelRow> resultTypeInfo;
+        private List<CatalogTable> tables;
         private MetadataConverter[] metadataConverters = new MetadataConverter[0];
         private ZoneId serverTimeZone = ZoneId.systemDefault();
         private DebeziumDeserializationConverterFactory userDefinedConverterFactory =
                 DebeziumDeserializationConverterFactory.DEFAULT;
+        private Map<TableId, Struct> tableIdTableChangeMap = new HashMap<>();
         private SchemaChangeResolver schemaChangeResolver;
 
         public SeaTunnelRowDebeziumDeserializeSchema build() {
             return new SeaTunnelRowDebeziumDeserializeSchema(
-                    physicalRowType,
                     metadataConverters,
-                    resultTypeInfo,
+                    tables,
                     serverTimeZone,
                     userDefinedConverterFactory,
-                    schemaChangeResolver);
+                    schemaChangeResolver,
+                    tableIdTableChangeMap);
         }
     }
 }
