@@ -20,23 +20,32 @@ package org.apache.seatunnel.connectors.seatunnel.console.sink;
 import org.apache.seatunnel.api.configuration.ReadonlyConfig;
 import org.apache.seatunnel.api.sink.SinkWriter;
 import org.apache.seatunnel.api.sink.SupportMultiTableSink;
+import org.apache.seatunnel.api.sink.SupportSchemaEvolutionSink;
+import org.apache.seatunnel.api.table.catalog.CatalogTable;
+import org.apache.seatunnel.api.table.schema.SchemaChangeType;
 import org.apache.seatunnel.api.table.type.SeaTunnelRow;
 import org.apache.seatunnel.api.table.type.SeaTunnelRowType;
 import org.apache.seatunnel.connectors.seatunnel.common.sink.AbstractSimpleSink;
 
+import java.util.Arrays;
+import java.util.List;
+import java.util.Optional;
+
 import static org.apache.seatunnel.connectors.seatunnel.console.sink.ConsoleSinkFactory.LOG_PRINT_DATA;
 import static org.apache.seatunnel.connectors.seatunnel.console.sink.ConsoleSinkFactory.LOG_PRINT_DELAY;
 
 public class ConsoleSink extends AbstractSimpleSink<SeaTunnelRow, Void>
-        implements SupportMultiTableSink {
+        implements SupportMultiTableSink, SupportSchemaEvolutionSink {
     private final SeaTunnelRowType seaTunnelRowType;
     private final boolean isPrintData;
     private final int delayMs;
+    private final CatalogTable catalogTable;
 
-    public ConsoleSink(SeaTunnelRowType seaTunnelRowType, ReadonlyConfig options) {
-        this.seaTunnelRowType = seaTunnelRowType;
+    public ConsoleSink(CatalogTable catalogTable, ReadonlyConfig options) {
+        this.catalogTable = catalogTable;
         this.isPrintData = options.get(LOG_PRINT_DATA);
         this.delayMs = options.get(LOG_PRINT_DELAY);
+        this.seaTunnelRowType = catalogTable.getTableSchema().toPhysicalRowDataType();
     }
 
     @Override
@@ -48,4 +57,18 @@ public class ConsoleSink extends AbstractSimpleSink<SeaTunnelRow, Void>
     public String getPluginName() {
         return "Console";
     }
+
+    @Override
+    public Optional<CatalogTable> getWriteCatalogTable() {
+        return Optional.ofNullable(catalogTable);
+    }
+
+    @Override
+    public List<SchemaChangeType> supports() {
+        return Arrays.asList(
+                SchemaChangeType.ADD_COLUMN,
+                SchemaChangeType.DROP_COLUMN,
+                SchemaChangeType.RENAME_COLUMN,
+                SchemaChangeType.UPDATE_COLUMN);
+    }
 }
