@@ -31,7 +31,7 @@ import org.apache.seatunnel.api.table.type.DecimalType;
 import org.apache.seatunnel.api.table.type.LocalTimeType;
 import org.apache.seatunnel.common.exception.CommonError;
 import org.apache.seatunnel.common.exception.SeaTunnelRuntimeException;
-import org.apache.seatunnel.connectors.doris.config.DorisOptions;
+import org.apache.seatunnel.connectors.doris.config.DorisSinkOptions;
 import org.apache.seatunnel.connectors.doris.datatype.DorisTypeConverterV1;
 import org.apache.seatunnel.connectors.doris.util.DorisCatalogUtil;
 
@@ -57,7 +57,9 @@ public class DorisCreateTableTest {
 
         columns.add(PhysicalColumn.of("id", BasicType.LONG_TYPE, (Long) null, true, null, ""));
         columns.add(PhysicalColumn.of("name", BasicType.STRING_TYPE, (Long) null, true, null, ""));
-        columns.add(PhysicalColumn.of("age", BasicType.INT_TYPE, (Long) null, true, null, ""));
+        columns.add(
+                PhysicalColumn.of(
+                        "age", BasicType.INT_TYPE, (Long) null, true, null, "test comment"));
         columns.add(PhysicalColumn.of("score", BasicType.INT_TYPE, (Long) null, true, null, ""));
         columns.add(PhysicalColumn.of("gender", BasicType.BYTE_TYPE, (Long) null, true, null, ""));
         columns.add(
@@ -122,7 +124,7 @@ public class DorisCreateTableTest {
         Assertions.assertEquals(
                 result,
                 "CREATE TABLE IF NOT EXISTS `test1`.`test2` (                                                                                                                                                   \n"
-                        + "`id` BIGINT NULL ,`age` INT NULL   ,       \n"
+                        + "`id` BIGINT NULL ,`age` INT NULL COMMENT 'test comment'  ,       \n"
                         + "`name` STRING NULL ,`score` INT NULL  , \n"
                         + "`create_time` DATETIME NOT NULL ,  \n"
                         + "`gender` TINYINT NULL   \n"
@@ -139,7 +141,7 @@ public class DorisCreateTableTest {
                         + "\"disable_auto_compaction\" = \"false\"\n"
                         + ")");
 
-        String createTemplate = DorisOptions.SAVE_MODE_CREATE_TEMPLATE.defaultValue();
+        String createTemplate = DorisSinkOptions.SAVE_MODE_CREATE_TEMPLATE.defaultValue();
         CatalogTable catalogTable =
                 CatalogTable.of(
                         TableIdentifier.of("test", "test1", "test2"),
@@ -169,7 +171,7 @@ public class DorisCreateTableTest {
                         SaveModePlaceHolder.getDisplay(primaryKeyHolder),
                         createTemplate,
                         primaryKeyHolder,
-                        DorisOptions.SAVE_MODE_CREATE_TEMPLATE.key());
+                        DorisSinkOptions.SAVE_MODE_CREATE_TEMPLATE.key());
         Assertions.assertEquals(
                 exceptSeaTunnelRuntimeException.getMessage(),
                 actualSeaTunnelRuntimeException.getMessage());
