@@ -46,6 +46,7 @@ import org.apache.seatunnel.connectors.seatunnel.hive.utils.HiveTableUtils;
 import org.apache.seatunnel.connectors.seatunnel.hive.utils.HiveTypeConvertor;
 
 import org.apache.commons.collections4.CollectionUtils;
+import org.apache.commons.lang3.StringUtils;
 import org.apache.hadoop.hive.metastore.api.FieldSchema;
 import org.apache.hadoop.hive.metastore.api.Table;
 
@@ -63,6 +64,7 @@ import java.util.Map;
 import static org.apache.seatunnel.connectors.seatunnel.file.config.BaseSinkConfig.FIELD_DELIMITER;
 import static org.apache.seatunnel.connectors.seatunnel.file.config.BaseSinkConfig.FILE_FORMAT_TYPE;
 import static org.apache.seatunnel.connectors.seatunnel.file.config.BaseSinkConfig.ROW_DELIMITER;
+import static org.apache.seatunnel.connectors.seatunnel.file.config.BaseSourceConfigOptions.NULL_FORMAT;
 
 @Getter
 public class HiveSourceConfig implements Serializable {
@@ -122,6 +124,19 @@ public class HiveSourceConfig implements Serializable {
             case TEXT:
                 // if the file format is text, we set the delim.
                 Map<String, String> parameters = table.getSd().getSerdeInfo().getParameters();
+                if (!readonlyConfig.getOptional(NULL_FORMAT).isPresent()) {
+                    String nullFormatKey = "serialization.null.format";
+                    String nullFormat = table.getParameters().get(nullFormatKey);
+                    if (StringUtils.isEmpty(nullFormat)) {
+                        nullFormat = parameters.get(nullFormatKey);
+                    }
+                    if (StringUtils.isEmpty(nullFormat)) {
+                        nullFormat = "\\N";
+                    }
+                    config =
+                            config.withValue(
+                                    NULL_FORMAT.key(), ConfigValueFactory.fromAnyRef(nullFormat));
+                }
                 config =
                         config.withValue(
                                         FIELD_DELIMITER.key(),
@@ -167,6 +182,9 @@ public class HiveSourceConfig implements Serializable {
         readonlyConfig
                 .getOptional(HdfsSourceConfigOptions.HDFS_SITE_PATH)
                 .ifPresent(hadoopConf::setHdfsSitePath);
+        readonlyConfig
+                .getOptional(HdfsSourceConfigOptions.KRB5_PATH)
+                .ifPresent(hadoopConf::setKrb5Path);
         readonlyConfig
                 .getOptional(HdfsSourceConfigOptions.KERBEROS_PRINCIPAL)
                 .ifPresent(hadoopConf::setKerberosPrincipal);
@@ -279,7 +297,9 @@ public class HiveSourceConfig implements Serializable {
         }
 
         SeaTunnelRowType seaTunnelRowType = new SeaTunnelRowType(fieldNames, fieldTypes);
-        readStrategy.setSeaTunnelRowTypeInfo(seaTunnelRowType);
+        readStrategy.setCatalogTable(
+                CatalogTableUtil.getCatalogTable(
+                        "hive", table.getDbName(), null, table.getTableName(), seaTunnelRowType));
         final SeaTunnelRowType finalSeatunnelRowType = readStrategy.getActualSeaTunnelRowTypeInfo();
 
         CatalogTable catalogTable = buildEmptyCatalogTable(readonlyConfig, table);
