@@ -18,6 +18,7 @@
 package org.apache.seatunnel.connectors.seatunnel.hive.storage;
 
 public class StorageFactory {
+
     public static Storage getStorageType(String hiveSdLocation) {
         if (hiveSdLocation.startsWith(StorageType.S3.name().toLowerCase())) {
             return new S3Storage();
@@ -25,6 +26,10 @@ public class StorageFactory {
             return new OSSStorage();
         } else if (hiveSdLocation.startsWith(StorageType.COS.name().toLowerCase())) {
             return new COSStorage();
+        } else if (hiveSdLocation.startsWith(StorageType.FILE.name().toLowerCase())) {
+            // Currently used in e2e, When Hive uses local files as storage, "file:" needs to be
+            // replaced with "file:/" to avoid being recognized as HDFS storage.
+            return new HDFSStorage(hiveSdLocation.replace("file:", "file:/"));
         } else {
             return new HDFSStorage(hiveSdLocation);
         }
