@@ -20,15 +20,17 @@ package org.apache.seatunnel.connectors.seatunnel.wechat.sink;
 import org.apache.seatunnel.shade.com.typesafe.config.Config;
 
 import org.apache.seatunnel.api.sink.SinkWriter;
-import org.apache.seatunnel.api.table.type.SeaTunnelRowType;
+import org.apache.seatunnel.api.table.catalog.CatalogTable;
 import org.apache.seatunnel.connectors.seatunnel.http.sink.HttpSink;
 import org.apache.seatunnel.connectors.seatunnel.http.sink.HttpSinkWriter;
 import org.apache.seatunnel.connectors.seatunnel.wechat.sink.config.WeChatSinkConfig;
 
+import java.util.Optional;
+
 public class WeChatSink extends HttpSink {
 
-    public WeChatSink(Config pluginConfig, SeaTunnelRowType rowType) {
-        super(pluginConfig, rowType);
+    public WeChatSink(Config pluginConfig, CatalogTable catalogTable) {
+        super(pluginConfig, catalogTable);
     }
 
     @Override
@@ -44,4 +46,9 @@ public class WeChatSink extends HttpSink {
                 new WeChatBotMessageSerializationSchema(
                         new WeChatSinkConfig(pluginConfig), seaTunnelRowType));
     }
+
+    @Override
+    public Optional<CatalogTable> getWriteCatalogTable() {
+        return super.getWriteCatalogTable();
+    }
 }
