@@ -34,6 +34,7 @@ import org.apache.seatunnel.api.table.catalog.exception.TableNotExistException;
 import org.apache.seatunnel.api.table.type.SeaTunnelDataType;
 import org.apache.seatunnel.connectors.seatunnel.iceberg.IcebergCatalogLoader;
 import org.apache.seatunnel.connectors.seatunnel.iceberg.config.CommonConfig;
+import org.apache.seatunnel.connectors.seatunnel.iceberg.utils.ExpressionUtils;
 import org.apache.seatunnel.connectors.seatunnel.iceberg.utils.SchemaUtils;
 
 import org.apache.iceberg.PartitionField;
@@ -44,9 +45,13 @@ import org.apache.iceberg.catalog.Namespace;
 import org.apache.iceberg.catalog.SupportsNamespaces;
 import org.apache.iceberg.catalog.TableIdentifier;
 import org.apache.iceberg.exceptions.NoSuchTableException;
+import org.apache.iceberg.expressions.Expression;
 import org.apache.iceberg.types.Types;
 
 import lombok.extern.slf4j.Slf4j;
+import net.sf.jsqlparser.parser.CCJSqlParserUtil;
+import net.sf.jsqlparser.statement.Statement;
+import net.sf.jsqlparser.statement.delete.Delete;
 
 import java.io.Closeable;
 import java.io.IOException;
@@ -57,12 +62,14 @@ import java.util.Set;
 import java.util.function.Function;
 import java.util.stream.Collectors;
 
-import static com.google.common.base.Preconditions.checkArgument;
 import static org.apache.seatunnel.connectors.seatunnel.iceberg.utils.SchemaUtils.toIcebergTableIdentifier;
 import static org.apache.seatunnel.connectors.seatunnel.iceberg.utils.SchemaUtils.toTablePath;
+import static org.apache.seatunnel.shade.com.google.common.base.Preconditions.checkArgument;
 
 @Slf4j
 public class IcebergCatalog implements Catalog {
+    public static final String PROPS_TABLE_COMMENT = "comment";
+
     private final String catalogName;
     private final ReadonlyConfig readonlyConfig;
     private final IcebergCatalogLoader icebergCatalogLoader;
@@ -210,7 +217,39 @@ public class IcebergCatalog implements Catalog {
 
     @Override
     public void executeSql(TablePath tablePath, String sql) {
-        throw new UnsupportedOperationException("Does not support executing custom SQL");
+        Delete delete;
+        try {
+            Statement statement = CCJSqlParserUtil.parse(sql);
+            delete = (Delete) statement;
+        } catch (Throwable e) {
+            throw new IllegalArgumentException(
+                    "Only support sql: delete from ... where ..., Not support: " + sql, e);
+        }
+
+        TablePath targetTablePath = TablePath.of(delete.getTable().getFullyQualifiedName(), false);
+        if (targetTablePath.getDatabaseName() == null) {
+            targetTablePath =
+                    TablePath.of(tablePath.getDatabaseName(), targetTablePath.getTableName());
+        }
+        if (!targetTablePath.equals(tablePath)) {
+            log.warn(
+                    "The delete table {} is not equal to the target table {}",
+                    targetTablePath,
+                    tablePath);
+        }
+
+        TableIdentifier icebergTableIdentifier = toIcebergTableIdentifier(targetTablePath);
+        Table table = catalog.loadTable(icebergTableIdentifier);
+        Expression expression = ExpressionUtils.convert(delete.getWhere(), table.schema());
+        catalog.loadTable(icebergTableIdentifier)
+                .newDelete()
+                .deleteFromRowFilter(expression)
+                .commit();
+        log.info(
+                "Delete table {} data success, sql [{}] to deleteFromRowFilter: {}",
+                targetTablePath,
+                sql,
+                expression);
     }
 
     public void truncateTable(TablePath tablePath, boolean ignoreIfNotExists)
@@ -246,6 +285,7 @@ public class IcebergCatalog implements Catalog {
                     builder.column(physicalColumn);
                 });
         Optional.ofNullable(schema.identifierFieldNames())
+                .filter(names -> !names.isEmpty())
                 .map(
                         (Function<Set<String>, Object>)
                                 names ->
@@ -257,14 +297,17 @@ public class IcebergCatalog implements Catalog {
                 icebergTable.spec().fields().stream()
                         .map(PartitionField::name)
                         .collect(Collectors.toList());
-
+        String comment =
+                Optional.ofNullable(icebergTable.properties())
+                        .map(e -> e.get(PROPS_TABLE_COMMENT))
+                        .orElse(null);
         return CatalogTable.of(
                 org.apache.seatunnel.api.table.catalog.TableIdentifier.of(
                         catalogName, tablePath.getDatabaseName(), tablePath.getTableName()),
                 builder.build(),
                 icebergTable.properties(),
                 partitionKeys,
-                null,
+                comment,
                 catalogName);
     }
 
