@@ -109,6 +109,12 @@ public class SinkConfig extends CommonConfig {
                     .defaultValue(DataSaveMode.APPEND_DATA)
                     .withDescription("data save mode");
 
+    public static final Option<String> DATA_SAVE_MODE_CUSTOM_SQL =
+            Options.key("custom_sql")
+                    .stringType()
+                    .noDefaultValue()
+                    .withDescription("custom delete data sql for data save mode");
+
     public static final Option<String> TABLES_DEFAULT_COMMIT_BRANCH =
             Options.key("iceberg.table.commit-branch")
                     .stringType()
@@ -128,6 +134,7 @@ public class SinkConfig extends CommonConfig {
     private boolean tableSchemaEvolutionEnabled;
     private SchemaSaveMode schemaSaveMode;
     private DataSaveMode dataSaveMode;
+    private String dataSaveModeSQL;
 
     public SinkConfig(ReadonlyConfig readonlyConfig) {
         super(readonlyConfig);
@@ -140,6 +147,7 @@ public class SinkConfig extends CommonConfig {
         this.tableSchemaEvolutionEnabled = readonlyConfig.get(TABLE_SCHEMA_EVOLUTION_ENABLED_PROP);
         this.schemaSaveMode = readonlyConfig.get(SCHEMA_SAVE_MODE);
         this.dataSaveMode = readonlyConfig.get(DATA_SAVE_MODE);
+        this.dataSaveModeSQL = readonlyConfig.get(DATA_SAVE_MODE_CUSTOM_SQL);
         this.commitBranch = readonlyConfig.get(TABLES_DEFAULT_COMMIT_BRANCH);
     }
 
