@@ -62,9 +62,9 @@ import java.util.Map;
 import java.util.Optional;
 import java.util.concurrent.ConcurrentHashMap;
 
-import static com.google.common.base.Preconditions.checkArgument;
-import static com.google.common.base.Preconditions.checkNotNull;
 import static org.apache.seatunnel.common.exception.CommonErrorCode.UNSUPPORTED_METHOD;
+import static org.apache.seatunnel.shade.com.google.common.base.Preconditions.checkArgument;
+import static org.apache.seatunnel.shade.com.google.common.base.Preconditions.checkNotNull;
 
 @Slf4j
 public abstract class AbstractJdbcCatalog implements Catalog {
@@ -178,24 +178,21 @@ public abstract class AbstractJdbcCatalog implements Catalog {
             DatabaseMetaData metaData = conn.getMetaData();
             Optional<PrimaryKey> primaryKey = getPrimaryKey(metaData, tablePath);
             List<ConstraintKey> constraintKeys = getConstraintKeys(metaData, tablePath);
-            try (PreparedStatement ps = conn.prepareStatement(getSelectColumnsSql(tablePath));
-                    ResultSet resultSet = ps.executeQuery()) {
+            TableSchema.Builder tableSchemaBuilder =
+                    buildColumnsReturnTablaSchemaBuilder(tablePath, conn);
+            // add primary key
+            primaryKey.ifPresent(tableSchemaBuilder::primaryKey);
+            // add constraint key
+            constraintKeys.forEach(tableSchemaBuilder::constraintKey);
+            TableIdentifier tableIdentifier = getTableIdentifier(tablePath);
+            return CatalogTable.of(
+                    tableIdentifier,
+                    tableSchemaBuilder.build(),
+                    buildConnectorOptions(tablePath),
+                    Collections.emptyList(),
+                    "",
+                    catalogName);
 
-                TableSchema.Builder builder = TableSchema.builder();
-                buildColumnsWithErrorCheck(tablePath, resultSet, builder);
-                // add primary key
-                primaryKey.ifPresent(builder::primaryKey);
-                // add constraint key
-                constraintKeys.forEach(builder::constraintKey);
-                TableIdentifier tableIdentifier = getTableIdentifier(tablePath);
-                return CatalogTable.of(
-                        tableIdentifier,
-                        builder.build(),
-                        buildConnectorOptions(tablePath),
-                        Collections.emptyList(),
-                        "",
-                        catalogName);
-            }
         } catch (SeaTunnelRuntimeException e) {
             throw e;
         } catch (Exception e) {
@@ -204,6 +201,16 @@ public abstract class AbstractJdbcCatalog implements Catalog {
         }
     }
 
+    protected TableSchema.Builder buildColumnsReturnTablaSchemaBuilder(
+            TablePath tablePath, Connection conn) throws SQLException {
+        TableSchema.Builder columnsBuilder = TableSchema.builder();
+        try (PreparedStatement ps = conn.prepareStatement(getSelectColumnsSql(tablePath));
+                ResultSet resultSet = ps.executeQuery()) {
+            buildColumnsWithErrorCheck(tablePath, resultSet, columnsBuilder);
+        }
+        return columnsBuilder;
+    }
+
     protected void buildColumnsWithErrorCheck(
             TablePath tablePath, ResultSet resultSet, TableSchema.Builder builder)
             throws SQLException {
