@@ -86,6 +86,16 @@ public class OracleTypeConverter implements TypeConverter<BasicTypeDefine> {
     public static final long BYTES_4GB = (long) Math.pow(2, 32);
     public static final OracleTypeConverter INSTANCE = new OracleTypeConverter();
 
+    private final boolean decimalTypeNarrowing;
+
+    public OracleTypeConverter() {
+        this(true);
+    }
+
+    public OracleTypeConverter(boolean decimalTypeNarrowing) {
+        this.decimalTypeNarrowing = decimalTypeNarrowing;
+    }
+
     @Override
     public String identifier() {
         return DatabaseIdentifier.ORACLE;
@@ -119,12 +129,14 @@ public class OracleTypeConverter implements TypeConverter<BasicTypeDefine> {
 
                 if (scale <= 0) {
                     int newPrecision = (int) (precision - scale);
-                    if (newPrecision == 1) {
-                        builder.dataType(BasicType.BOOLEAN_TYPE);
-                    } else if (newPrecision <= 9) {
-                        builder.dataType(BasicType.INT_TYPE);
-                    } else if (newPrecision <= 18) {
-                        builder.dataType(BasicType.LONG_TYPE);
+                    if (newPrecision <= 18 && decimalTypeNarrowing) {
+                        if (newPrecision == 1) {
+                            builder.dataType(BasicType.BOOLEAN_TYPE);
+                        } else if (newPrecision <= 9) {
+                            builder.dataType(BasicType.INT_TYPE);
+                        } else {
+                            builder.dataType(BasicType.LONG_TYPE);
+                        }
                     } else if (newPrecision < 38) {
                         builder.dataType(new DecimalType(newPrecision, 0));
                         builder.columnLength((long) newPrecision);
@@ -161,7 +173,7 @@ public class OracleTypeConverter implements TypeConverter<BasicTypeDefine> {
             case ORACLE_VARCHAR:
             case ORACLE_VARCHAR2:
                 builder.dataType(BasicType.STRING_TYPE);
-                builder.columnLength(typeDefine.getLength());
+                builder.columnLength(TypeDefineUtils.charTo4ByteLength(typeDefine.getLength()));
                 break;
             case ORACLE_NCHAR:
             case ORACLE_NVARCHAR2:
