@@ -17,6 +17,8 @@
 
 package org.apache.seatunnel.connectors.seatunnel.jdbc.catalog.psql;
 
+import org.apache.seatunnel.shade.com.google.common.collect.Lists;
+
 import org.apache.seatunnel.api.table.catalog.CatalogTable;
 import org.apache.seatunnel.api.table.catalog.Column;
 import org.apache.seatunnel.api.table.catalog.ConstraintKey;
@@ -30,11 +32,10 @@ import org.apache.seatunnel.connectors.seatunnel.jdbc.internal.dialect.DatabaseI
 import org.junit.jupiter.api.Assertions;
 import org.junit.jupiter.api.Test;
 
-import com.google.common.collect.Lists;
-
 import java.util.Arrays;
 import java.util.Collections;
 import java.util.List;
+import java.util.regex.Pattern;
 
 class PostgresCreateTableSqlBuilderTest {
 
@@ -49,17 +50,18 @@ class PostgresCreateTableSqlBuilderTest {
                             String createTableSql =
                                     postgresCreateTableSqlBuilder.build(
                                             catalogTable.getTableId().toTablePath());
-                            Assertions.assertEquals(
-                                    "CREATE TABLE \"test\" (\n"
+                            String pattern =
+                                    "CREATE TABLE \"test\" \\(\n"
                                             + "\"id\" int4 NOT NULL PRIMARY KEY,\n"
                                             + "\"name\" text NOT NULL,\n"
                                             + "\"age\" int4 NOT NULL,\n"
-                                            + "\tCONSTRAINT unique_name UNIQUE (\"name\")\n"
-                                            + ");",
-                                    createTableSql);
+                                            + "\tCONSTRAINT \"([a-zA-Z0-9]+)\" UNIQUE \\(\"name\"\\)\n"
+                                            + "\\);";
+                            Assertions.assertTrue(
+                                    Pattern.compile(pattern).matcher(createTableSql).find());
+
                             Assertions.assertEquals(
-                                    Lists.newArrayList(
-                                            "CREATE INDEX test_index_age ON \"test\"(\"age\");"),
+                                    Lists.newArrayList("CREATE INDEX ON \"test\"(\"age\");"),
                                     postgresCreateTableSqlBuilder.getCreateIndexSqls());
 
                             // skip index
