@@ -23,6 +23,7 @@ import org.apache.seatunnel.api.common.PrepareFailException;
 import org.apache.seatunnel.api.common.SeaTunnelAPIErrorCode;
 import org.apache.seatunnel.api.sink.SeaTunnelSink;
 import org.apache.seatunnel.api.sink.SinkWriter;
+import org.apache.seatunnel.api.table.catalog.CatalogTable;
 import org.apache.seatunnel.api.table.type.SeaTunnelRow;
 import org.apache.seatunnel.api.table.type.SeaTunnelRowType;
 import org.apache.seatunnel.common.config.CheckConfigUtil;
@@ -38,6 +39,7 @@ import org.apache.seatunnel.connectors.seatunnel.rocketmq.exception.RocketMqConn
 import com.google.auto.service.AutoService;
 
 import java.io.IOException;
+import java.util.Optional;
 
 import static org.apache.seatunnel.connectors.seatunnel.rocketmq.config.Config.ACCESS_KEY;
 import static org.apache.seatunnel.connectors.seatunnel.rocketmq.config.Config.ACL_ENABLED;
@@ -72,6 +74,9 @@ public class RocketMqSink extends AbstractSimpleSink<SeaTunnelRow, Void> {
         }
         producerMetadata = new ProducerMetadata();
         producerMetadata.setTopic(config.getString(ProducerConfig.TOPIC.key()));
+        if (config.hasPath(ProducerConfig.TAG.key())) {
+            producerMetadata.setTag(config.getString(ProducerConfig.TAG.key()));
+        }
         RocketMqBaseConfiguration.Builder baseConfigurationBuilder =
                 RocketMqBaseConfiguration.newBuilder()
                         .producer()
@@ -161,4 +166,9 @@ public class RocketMqSink extends AbstractSimpleSink<SeaTunnelRow, Void> {
             throws IOException {
         return new RocketMqSinkWriter(producerMetadata, seaTunnelRowType);
     }
+
+    @Override
+    public Optional<CatalogTable> getWriteCatalogTable() {
+        return super.getWriteCatalogTable();
+    }
 }
