@@ -17,6 +17,8 @@
 
 package org.apache.seatunnel.connectors.seatunnel.starrocks.catalog;
 
+import org.apache.seatunnel.shade.com.google.common.base.Preconditions;
+
 import org.apache.seatunnel.api.table.catalog.Catalog;
 import org.apache.seatunnel.api.table.catalog.CatalogTable;
 import org.apache.seatunnel.api.table.catalog.PhysicalColumn;
@@ -38,6 +40,7 @@ import org.apache.seatunnel.api.table.type.PrimitiveByteArrayType;
 import org.apache.seatunnel.api.table.type.SeaTunnelDataType;
 import org.apache.seatunnel.common.exception.CommonErrorCodeDeprecated;
 import org.apache.seatunnel.common.utils.JdbcUrlUtil;
+import org.apache.seatunnel.connectors.seatunnel.starrocks.config.StarRocksSinkOptions;
 import org.apache.seatunnel.connectors.seatunnel.starrocks.exception.StarRocksConnectorException;
 import org.apache.seatunnel.connectors.seatunnel.starrocks.sink.StarRocksSaveModeUtil;
 
@@ -46,7 +49,6 @@ import org.apache.commons.lang3.StringUtils;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import com.google.common.base.Preconditions;
 import com.mysql.cj.MysqlType;
 import lombok.extern.slf4j.Slf4j;
 
@@ -202,11 +204,12 @@ public class StarRocksCatalog implements Catalog {
     public void createTable(TablePath tablePath, CatalogTable table, boolean ignoreIfExists)
             throws TableAlreadyExistException, DatabaseNotExistException, CatalogException {
         this.createTable(
-                StarRocksSaveModeUtil.getCreateTableSql(
+                StarRocksSaveModeUtil.INSTANCE.getCreateTableSql(
                         template,
                         tablePath.getDatabaseName(),
                         tablePath.getTableName(),
-                        table.getTableSchema()));
+                        table.getTableSchema(),
+                        StarRocksSinkOptions.SAVE_MODE_CREATE_TEMPLATE.key()));
     }
 
     @Override
@@ -214,7 +217,9 @@ public class StarRocksCatalog implements Catalog {
             throws TableNotExistException, CatalogException {
         try {
             conn.createStatement()
-                    .execute(StarRocksSaveModeUtil.getDropTableSql(tablePath, ignoreIfNotExists));
+                    .execute(
+                            StarRocksSaveModeUtil.INSTANCE.getDropTableSql(
+                                    tablePath, ignoreIfNotExists));
         } catch (Exception e) {
             throw new CatalogException(
                     String.format("Failed listing database in catalog %s", catalogName), e);
@@ -226,7 +231,7 @@ public class StarRocksCatalog implements Catalog {
         try {
             if (ignoreIfNotExists) {
                 conn.createStatement()
-                        .execute(StarRocksSaveModeUtil.getTruncateTableSql(tablePath));
+                        .execute(StarRocksSaveModeUtil.INSTANCE.getTruncateTableSql(tablePath));
             }
         } catch (Exception e) {
             throw new CatalogException(
@@ -263,7 +268,7 @@ public class StarRocksCatalog implements Catalog {
         try {
             conn.createStatement()
                     .execute(
-                            StarRocksSaveModeUtil.getCreateDatabaseSql(
+                            StarRocksSaveModeUtil.INSTANCE.getCreateDatabaseSql(
                                     tablePath.getDatabaseName(), ignoreIfExists));
         } catch (Exception e) {
             throw new CatalogException(
@@ -277,7 +282,7 @@ public class StarRocksCatalog implements Catalog {
         try {
             conn.createStatement()
                     .execute(
-                            StarRocksSaveModeUtil.getDropDatabaseSql(
+                            StarRocksSaveModeUtil.INSTANCE.getDropDatabaseSql(
                                     tablePath.getDatabaseName(), ignoreIfNotExists));
         } catch (Exception e) {
             throw new CatalogException(
@@ -359,8 +364,6 @@ public class StarRocksCatalog implements Catalog {
         options.put("connector", "starrocks");
         options.put("url", baseUrl + tablePath.getDatabaseName());
         options.put("table-name", tablePath.getFullName());
-        options.put("username", username);
-        options.put("password", pwd);
         return options;
     }
 
@@ -496,18 +499,22 @@ public class StarRocksCatalog implements Catalog {
         if (actionType == ActionType.CREATE_TABLE) {
             Preconditions.checkArgument(catalogTable.isPresent(), "CatalogTable cannot be null");
             return new SQLPreviewResult(
-                    StarRocksSaveModeUtil.getCreateTableSql(
+                    StarRocksSaveModeUtil.INSTANCE.getCreateTableSql(
                             template,
                             tablePath.getDatabaseName(),
                             tablePath.getTableName(),
-                            catalogTable.get().getTableSchema()));
+                            catalogTable.get().getTableSchema(),
+                            StarRocksSinkOptions.SAVE_MODE_CREATE_TEMPLATE.key()));
         } else if (actionType == ActionType.DROP_TABLE) {
-            return new SQLPreviewResult(StarRocksSaveModeUtil.getDropTableSql(tablePath, true));
+            return new SQLPreviewResult(
+                    StarRocksSaveModeUtil.INSTANCE.getDropTableSql(tablePath, true));
         } else if (actionType == ActionType.TRUNCATE_TABLE) {
-            return new SQLPreviewResult(StarRocksSaveModeUtil.getTruncateTableSql(tablePath));
+            return new SQLPreviewResult(
+                    StarRocksSaveModeUtil.INSTANCE.getTruncateTableSql(tablePath));
         } else if (actionType == ActionType.CREATE_DATABASE) {
             return new SQLPreviewResult(
-                    StarRocksSaveModeUtil.getCreateDatabaseSql(tablePath.getDatabaseName(), true));
+                    StarRocksSaveModeUtil.INSTANCE.getCreateDatabaseSql(
+                            tablePath.getDatabaseName(), true));
         } else if (actionType == ActionType.DROP_DATABASE) {
             return new SQLPreviewResult(
                     "DROP DATABASE IF EXISTS `" + tablePath.getDatabaseName() + "`");
