@@ -17,6 +17,13 @@
 
 package org.apache.seatunnel.connectors.seatunnel.starrocks.sink;
 
+import org.apache.seatunnel.api.sink.SupportMultiTableSinkWriter;
+import org.apache.seatunnel.api.sink.SupportSchemaEvolutionSinkWriter;
+import org.apache.seatunnel.api.table.catalog.TablePath;
+import org.apache.seatunnel.api.table.catalog.TableSchema;
+import org.apache.seatunnel.api.table.catalog.exception.CatalogException;
+import org.apache.seatunnel.api.table.schema.event.SchemaChangeEvent;
+import org.apache.seatunnel.api.table.schema.handler.TableSchemaChangeEventDispatcher;
 import org.apache.seatunnel.api.table.type.SeaTunnelRow;
 import org.apache.seatunnel.api.table.type.SeaTunnelRowType;
 import org.apache.seatunnel.common.exception.CommonErrorCodeDeprecated;
@@ -27,31 +34,36 @@ import org.apache.seatunnel.connectors.seatunnel.starrocks.exception.StarRocksCo
 import org.apache.seatunnel.connectors.seatunnel.starrocks.serialize.StarRocksCsvSerializer;
 import org.apache.seatunnel.connectors.seatunnel.starrocks.serialize.StarRocksISerializer;
 import org.apache.seatunnel.connectors.seatunnel.starrocks.serialize.StarRocksJsonSerializer;
-import org.apache.seatunnel.connectors.seatunnel.starrocks.serialize.StarRocksSinkOP;
+import org.apache.seatunnel.connectors.seatunnel.starrocks.util.SchemaUtils;
 
 import lombok.SneakyThrows;
 import lombok.extern.slf4j.Slf4j;
 
 import java.io.IOException;
-import java.util.Arrays;
-import java.util.List;
+import java.sql.Connection;
+import java.sql.DriverManager;
+import java.sql.SQLException;
 import java.util.Optional;
-import java.util.stream.Collectors;
 
 @Slf4j
-public class StarRocksSinkWriter extends AbstractSinkWriter<SeaTunnelRow, Void> {
+public class StarRocksSinkWriter extends AbstractSinkWriter<SeaTunnelRow, Void>
+        implements SupportMultiTableSinkWriter<Void>, SupportSchemaEvolutionSinkWriter {
+    private StarRocksISerializer serializer;
+    private StarRocksSinkManager manager;
+    private TableSchema tableSchema;
+    private final SinkConfig sinkConfig;
+    private final TablePath sinkTablePath;
+    private final TableSchemaChangeEventDispatcher tableSchemaChangeEventDispatcher =
+            new TableSchemaChangeEventDispatcher();
 
-    private final StarRocksISerializer serializer;
-    private final StarRocksSinkManager manager;
-
-    public StarRocksSinkWriter(SinkConfig sinkConfig, SeaTunnelRowType seaTunnelRowType) {
-        List<String> fieldNames =
-                Arrays.stream(seaTunnelRowType.getFieldNames()).collect(Collectors.toList());
-        if (sinkConfig.isEnableUpsertDelete()) {
-            fieldNames.add(StarRocksSinkOP.COLUMN_KEY);
-        }
+    public StarRocksSinkWriter(
+            SinkConfig sinkConfig, TableSchema tableSchema, TablePath tablePath) {
+        this.tableSchema = tableSchema;
+        SeaTunnelRowType seaTunnelRowType = tableSchema.toPhysicalRowDataType();
         this.serializer = createSerializer(sinkConfig, seaTunnelRowType);
-        this.manager = new StarRocksSinkManager(sinkConfig, fieldNames);
+        this.manager = new StarRocksSinkManager(sinkConfig, tableSchema);
+        this.sinkConfig = sinkConfig;
+        this.sinkTablePath = tablePath;
     }
 
     @Override
@@ -68,6 +80,31 @@ public class StarRocksSinkWriter extends AbstractSinkWriter<SeaTunnelRow, Void>
         manager.write(record);
     }
 
+    @Override
+    public void applySchemaChange(SchemaChangeEvent event) {
+        this.tableSchema = tableSchemaChangeEventDispatcher.reset(tableSchema).apply(event);
+        SeaTunnelRowType seaTunnelRowType = tableSchema.toPhysicalRowDataType();
+        this.serializer = createSerializer(sinkConfig, seaTunnelRowType);
+        this.manager = new StarRocksSinkManager(sinkConfig, tableSchema);
+
+        try {
+            Class.forName("com.mysql.cj.jdbc.Driver");
+        } catch (ClassNotFoundException e) {
+            throw new RuntimeException("Failed to load MySQL JDBC driver", e);
+        }
+
+        try (Connection conn =
+                DriverManager.getConnection(
+                        sinkConfig.getJdbcUrl(),
+                        sinkConfig.getUsername(),
+                        sinkConfig.getPassword())) {
+            SchemaUtils.applySchemaChange(event, conn, sinkTablePath);
+        } catch (SQLException e) {
+            throw new CatalogException(
+                    String.format("Failed connecting to %s via JDBC.", sinkConfig.getJdbcUrl()), e);
+        }
+    }
+
     @SneakyThrows
     @Override
     public Optional<Void> prepareCommit() {
@@ -89,7 +126,7 @@ public class StarRocksSinkWriter extends AbstractSinkWriter<SeaTunnelRow, Void>
         }
     }
 
-    public static StarRocksISerializer createSerializer(
+    public StarRocksISerializer createSerializer(
             SinkConfig sinkConfig, SeaTunnelRowType seaTunnelRowType) {
         if (SinkConfig.StreamLoadFormat.CSV.equals(sinkConfig.getLoadFormat())) {
             return new StarRocksCsvSerializer(
