@@ -19,11 +19,14 @@ package org.apache.seatunnel.connectors.seatunnel.tablestore.config;
 
 import org.apache.seatunnel.shade.com.typesafe.config.Config;
 
+import org.apache.seatunnel.api.configuration.ReadonlyConfig;
+
 import lombok.AllArgsConstructor;
 import lombok.Data;
 
 import java.io.Serializable;
 import java.util.List;
+import java.util.Map;
 
 import static org.apache.seatunnel.connectors.seatunnel.tablestore.config.TablestoreConfig.BATCH_SIZE;
 
@@ -45,6 +48,8 @@ public class TablestoreOptions implements Serializable {
 
     public int batchSize = Integer.parseInt(BATCH_SIZE.defaultValue());
 
+    public TablestoreOptions() {}
+
     public TablestoreOptions(Config config) {
         this.endpoint = config.getString(TablestoreConfig.END_POINT.key());
         this.instanceName = config.getString(TablestoreConfig.INSTANCE_NAME.key());
@@ -57,4 +62,18 @@ public class TablestoreOptions implements Serializable {
             this.batchSize = config.getInt(BATCH_SIZE.key());
         }
     }
+
+    public static TablestoreOptions of(ReadonlyConfig config) {
+        Map<String, Object> map = config.getSourceMap();
+        TablestoreOptions tablestoreOptions = new TablestoreOptions();
+        tablestoreOptions.setEndpoint(config.get(TablestoreConfig.END_POINT));
+        tablestoreOptions.setInstanceName(config.get(TablestoreConfig.INSTANCE_NAME));
+        tablestoreOptions.setAccessKeyId(config.get(TablestoreConfig.ACCESS_KEY_ID));
+        tablestoreOptions.setAccessKeySecret(config.get(TablestoreConfig.ACCESS_KEY_SECRET));
+        tablestoreOptions.setTable(config.get(TablestoreConfig.TABLE));
+        List<String> keys = (List<String>) map.get(TablestoreConfig.PRIMARY_KEYS.key());
+
+        tablestoreOptions.setPrimaryKeys(keys);
+        return tablestoreOptions;
+    }
 }
