@@ -66,7 +66,8 @@ CREATE TABLE mysql_cdc_e2e_source_table
     `f_tinyint_unsigned`   tinyint unsigned               DEFAULT NULL,
     `f_json`               json                           DEFAULT NULL,
     `f_year`               year                           DEFAULT NULL,
-    PRIMARY KEY (`id`)
+    PRIMARY KEY (`id`),
+    UNIQUE KEY uniq_key_f (`id`, `f_int`, `f_bigint`) USING BTREE
 ) ENGINE = InnoDB
   AUTO_INCREMENT = 2
   DEFAULT CHARSET = utf8mb4
@@ -116,7 +117,8 @@ CREATE TABLE mysql_cdc_e2e_source_table2
     `f_tinyint_unsigned`   tinyint unsigned               DEFAULT NULL,
     `f_json`               json                           DEFAULT NULL,
     `f_year`               year                           DEFAULT NULL,
-    PRIMARY KEY (`id`)
+    PRIMARY KEY (`id`),
+    UNIQUE KEY uniq_key_f (`id`, `f_int`, `f_bigint`) USING BTREE
 ) ENGINE = InnoDB
   AUTO_INCREMENT = 2
   DEFAULT CHARSET = utf8mb4
