@@ -17,17 +17,16 @@
 
 package org.apache.seatunnel.e2e.connector.doris;
 
+import org.apache.seatunnel.shade.com.google.common.collect.Lists;
+
 import org.apache.seatunnel.e2e.common.TestResource;
 import org.apache.seatunnel.e2e.common.TestSuiteBase;
 
 import org.junit.jupiter.api.AfterAll;
 import org.junit.jupiter.api.BeforeAll;
 import org.testcontainers.containers.GenericContainer;
-import org.testcontainers.containers.output.Slf4jLogConsumer;
 import org.testcontainers.lifecycle.Startables;
-import org.testcontainers.utility.DockerLoggerFactory;
 
-import com.google.common.collect.Lists;
 import lombok.extern.slf4j.Slf4j;
 
 import java.net.MalformedURLException;
@@ -39,6 +38,8 @@ import java.sql.ResultSet;
 import java.sql.SQLException;
 import java.sql.Statement;
 import java.time.Duration;
+import java.util.ArrayList;
+import java.util.List;
 import java.util.Properties;
 import java.util.concurrent.TimeUnit;
 import java.util.concurrent.locks.LockSupport;
@@ -70,17 +71,18 @@ public abstract class AbstractDorisIT extends TestSuiteBase implements TestResou
     protected static final String DRIVER_CLASS = "com.mysql.cj.jdbc.Driver";
     protected static final String DRIVER_JAR =
             "https://repo1.maven.org/maven2/com/mysql/mysql-connector-j/8.0.32/mysql-connector-j-8.0.32.jar";
+    private static final boolean isGithubActionsEnv =
+            "true".equalsIgnoreCase(System.getenv("GITHUB_ACTIONS"));
 
     @BeforeAll
     @Override
     public void startUp() {
+        log.info("isGithubActionsEnv: {}", isGithubActionsEnv);
         container =
                 new GenericContainer<>(DOCKER_IMAGE)
                         .withNetwork(NETWORK)
                         .withNetworkAliases(HOST)
-                        .withPrivilegedMode(true)
-                        .withLogConsumer(
-                                new Slf4jLogConsumer(DockerLoggerFactory.getLogger(DOCKER_IMAGE)));
+                        .withPrivilegedMode(true);
         container.setPortBindings(
                 Lists.newArrayList(
                         String.format("%s:%s", QUERY_PORT, QUERY_PORT),
@@ -88,15 +90,17 @@ public abstract class AbstractDorisIT extends TestSuiteBase implements TestResou
                         String.format("%s:%s", BE_HTTP_PORT, BE_HTTP_PORT)));
         Startables.deepStart(Stream.of(container)).join();
         log.info("doris container started");
-        given().ignoreExceptions()
+        given().pollDelay(20, TimeUnit.SECONDS)
                 .await()
                 .atMost(360, TimeUnit.SECONDS)
                 .untilAsserted(this::initializeJdbcConnection);
+        log.info("doris initialized");
     }
 
     protected void initializeJdbcConnection()
             throws SQLException, ClassNotFoundException, MalformedURLException,
                     InstantiationException, IllegalAccessException {
+        log.info("doris initializing ...");
         URLClassLoader urlClassLoader =
                 new URLClassLoader(new URL[] {new URL(DRIVER_JAR)}, DorisIT.class.getClassLoader());
         Thread.currentThread().setContextClassLoader(urlClassLoader);
@@ -105,7 +109,9 @@ public abstract class AbstractDorisIT extends TestSuiteBase implements TestResou
         props.put("user", USERNAME);
         props.put("password", PASSWORD);
         jdbcConnection = driver.connect(String.format(URL, container.getHost()), props);
-        initializeBE();
+        if (isGithubActionsEnv) {
+            initializeBE();
+        }
         try (Statement statement = jdbcConnection.createStatement()) {
             statement.execute(SET_SQL);
             statement.execute(SET_CONNECTIONS);
@@ -123,14 +129,21 @@ public abstract class AbstractDorisIT extends TestSuiteBase implements TestResou
     // cross-container access failure. Delete the BE and add it again
     private void initializeBE() {
         try (Statement statement = jdbcConnection.createStatement()) {
-            ResultSet resultSet = statement.executeQuery(SHOW_FE);
-            String feIp = null;
-            while (resultSet.next()) {
-                feIp = resultSet.getString("Host");
+            ResultSet beResultSet = statement.executeQuery(SHOW_BE);
+            List<String> beList = new ArrayList<>();
+            while (beResultSet.next()) {
+                beList.add(beResultSet.getString("Host"));
+            }
+            if (beList.stream().anyMatch("127.0.0.1"::equals)) {
+                ResultSet resultSet = statement.executeQuery(SHOW_FE);
+                String feIp = null;
+                while (resultSet.next()) {
+                    feIp = resultSet.getString("Host");
+                }
+                statement.execute(DROP_BE);
+                statement.execute(String.format(ADD_BE, feIp));
+                log.info("doris BE initialized");
             }
-            statement.execute(DROP_BE);
-            statement.execute(String.format(ADD_BE, feIp));
-
         } catch (SQLException e) {
             throw new RuntimeException(e);
         }
