@@ -35,6 +35,8 @@ import org.apache.seatunnel.api.table.type.DecimalType;
 import org.apache.seatunnel.connectors.doris.catalog.DorisCatalog;
 import org.apache.seatunnel.connectors.doris.catalog.DorisCatalogFactory;
 import org.apache.seatunnel.connectors.doris.config.DorisOptions;
+import org.apache.seatunnel.connectors.doris.config.DorisSinkOptions;
+import org.apache.seatunnel.connectors.doris.config.DorisSourceOptions;
 import org.apache.seatunnel.connectors.doris.sink.DorisSinkFactory;
 import org.apache.seatunnel.connectors.doris.source.DorisSourceFactory;
 
@@ -224,13 +226,29 @@ public class DorisCatalogIT extends AbstractDorisIT {
                                 put(DorisOptions.TABLE.key(), "test4");
                                 put(DorisOptions.USERNAME.key(), USERNAME);
                                 put(DorisOptions.PASSWORD.key(), PASSWORD);
-                                put(DorisOptions.NEEDS_UNSUPPORTED_TYPE_CASTING.key(), true);
+                                put(DorisSinkOptions.NEEDS_UNSUPPORTED_TYPE_CASTING.key(), true);
                             }
                         });
-        upstreamTable
-                .getTableSchema()
-                .getColumns()
-                .add(PhysicalColumn.of("v3", new DecimalType(66, 22), 66, false, null, "v3"));
+
+        upstreamTable =
+                CatalogTable.of(
+                        upstreamTable.getTableId(),
+                        TableSchema.builder()
+                                .columns(upstreamTable.getTableSchema().getColumns())
+                                .column(
+                                        PhysicalColumn.of(
+                                                "v3",
+                                                new DecimalType(66, 22),
+                                                66,
+                                                false,
+                                                null,
+                                                "v3"))
+                                .primaryKey(upstreamTable.getTableSchema().getPrimaryKey())
+                                .constraintKey(upstreamTable.getTableSchema().getConstraintKeys())
+                                .build(),
+                        upstreamTable.getOptions(),
+                        upstreamTable.getPartitionKeys(),
+                        upstreamTable.getComment());
         CatalogTable newTable = assertCreateTable(upstreamTable, config5, "test4.test4");
         Assertions.assertEquals(
                 BasicType.DOUBLE_TYPE, newTable.getTableSchema().getColumns().get(4).getDataType());
@@ -260,6 +278,9 @@ public class DorisCatalogIT extends AbstractDorisIT {
                 createdTable.getTableSchema().getColumns().stream()
                         .map(Column::getName)
                         .collect(Collectors.toList()));
+        Assertions.assertEquals(
+                "k1", createdTable.getTableSchema().getColumns().get(0).getComment());
+        ;
         return createdTable;
     }
 
@@ -279,7 +300,8 @@ public class DorisCatalogIT extends AbstractDorisIT {
                                                         put(DorisOptions.USERNAME.key(), USERNAME);
                                                         put(DorisOptions.PASSWORD.key(), PASSWORD);
                                                         put(
-                                                                DorisOptions.DORIS_READ_FIELD.key(),
+                                                                DorisSourceOptions.DORIS_READ_FIELD
+                                                                        .key(),
                                                                 "k1,k2");
                                                         put(
                                                                 DorisOptions.FENODES.key(),
