@@ -17,6 +17,8 @@
 
 package org.apache.seatunnel.connectors.seatunnel.jdbc;
 
+import org.apache.seatunnel.shade.com.google.common.collect.Lists;
+
 import org.apache.seatunnel.e2e.common.TestResource;
 import org.apache.seatunnel.e2e.common.TestSuiteBase;
 import org.apache.seatunnel.e2e.common.container.ContainerExtendedFactory;
@@ -34,7 +36,6 @@ import org.testcontainers.lifecycle.Startables;
 import org.testcontainers.utility.DockerImageName;
 import org.testcontainers.utility.DockerLoggerFactory;
 
-import com.google.common.collect.Lists;
 import lombok.extern.slf4j.Slf4j;
 
 import java.io.IOException;
@@ -91,7 +92,9 @@ public class JdbcPostgresIdentifierIT extends TestSuiteBase implements TestResou
                     + "  multilinestring geometry(MULTILINESTRING, 4326),\n"
                     + "  multipolygon geometry(MULTIPOLYGON, 4326),\n"
                     + "  geometrycollection geometry(GEOMETRYCOLLECTION, 4326),\n"
-                    + "  geog geography(POINT, 4326)\n"
+                    + "  geog geography(POINT, 4326),\n"
+                    + "  inet_col INET,\n"
+                    + "  char_one_col CHAR(1)\n"
                     + ")";
     private static final String PG_SINK_DDL =
             "CREATE TABLE IF NOT EXISTS test.public.\"PG_IDE_SINK_TABLE\" (\n"
@@ -122,7 +125,9 @@ public class JdbcPostgresIdentifierIT extends TestSuiteBase implements TestResou
                     + "    \"MULTILINESTRING\" varchar(2000) NULL,\n"
                     + "    \"MULTIPOLYGON\" varchar(2000) NULL,\n"
                     + "    \"GEOMETRYCOLLECTION\" varchar(2000) NULL,\n"
-                    + "    \"GEOG\" varchar(2000) NULL\n"
+                    + "    \"GEOG\" varchar(2000) NULL,\n"
+                    + "    \"INET_COL\" INET NULL,\n"
+                    + "    \"CHAR_ONE_COL\" CHAR(1) NULL\n"
                     + "  )";
 
     private static final String SOURCE_SQL =
@@ -154,7 +159,9 @@ public class JdbcPostgresIdentifierIT extends TestSuiteBase implements TestResou
                     + "multilinestring,\n"
                     + "multipolygon,\n"
                     + "geometrycollection,\n"
-                    + "geog\n"
+                    + "geog,\n"
+                    + "inet_col,\n"
+                    + "char_one_col\n"
                     + " from pg_ide_source_table";
     private static final String SINK_SQL =
             "SELECT\n"
@@ -185,7 +192,9 @@ public class JdbcPostgresIdentifierIT extends TestSuiteBase implements TestResou
                     + "  CAST(\"MULTILINESTRING\" AS GEOMETRY) AS MULTILINESTRING,\n"
                     + "  CAST(\"MULTIPOLYGON\" AS GEOMETRY) AS MULTILINESTRING,\n"
                     + "  CAST(\"GEOMETRYCOLLECTION\" AS GEOMETRY) AS GEOMETRYCOLLECTION,\n"
-                    + "  CAST(\"GEOG\" AS GEOGRAPHY) AS GEOG\n"
+                    + "  CAST(\"GEOG\" AS GEOGRAPHY) AS GEOG,\n"
+                    + "  \"INET_COL\",\n"
+                    + "  \"CHAR_ONE_COL\"\n"
                     + "FROM\n"
                     + "  \"PG_IDE_SINK_TABLE\";";
 
@@ -276,7 +285,9 @@ public class JdbcPostgresIdentifierIT extends TestSuiteBase implements TestResou
                                 + "    multilinestring,\n"
                                 + "    multipolygon,\n"
                                 + "    geometrycollection,\n"
-                                + "    geog\n"
+                                + "    geog,\n"
+                                + "    inet_col,\n"
+                                + "    char_one_col\n"
                                 + "  )\n"
                                 + "VALUES\n"
                                 + "  (\n"
@@ -327,7 +338,9 @@ public class JdbcPostgresIdentifierIT extends TestSuiteBase implements TestResou
                                 + "      'GEOMETRYCOLLECTION(POINT(-122.3462 47.5921), LINESTRING(-122.3460 47.5924, -122.3457 47.5924))',\n"
                                 + "      4326\n"
                                 + "    ),\n"
-                                + "    ST_GeographyFromText('POINT(-122.3452 47.5925)')\n"
+                                + "    ST_GeographyFromText('POINT(-122.3452 47.5925)'),\n"
+                                + "    '192.168.1.1',\n"
+                                + "    'T'\n"
                                 + "  )");
             }
 
