@@ -17,6 +17,7 @@
 
 package org.apache.seatunnel.connectors.seatunnel.jdbc;
 
+import org.apache.seatunnel.api.table.type.SeaTunnelRow;
 import org.apache.seatunnel.common.exception.SeaTunnelRuntimeException;
 import org.apache.seatunnel.common.utils.ExceptionUtils;
 import org.apache.seatunnel.e2e.common.TestResource;
@@ -28,6 +29,7 @@ import org.apache.seatunnel.e2e.common.junit.DisabledOnContainer;
 import org.apache.seatunnel.e2e.common.junit.TestContainerExtension;
 
 import org.apache.commons.lang3.StringUtils;
+import org.apache.commons.lang3.tuple.Pair;
 
 import org.awaitility.Awaitility;
 import org.junit.jupiter.api.AfterAll;
@@ -44,7 +46,6 @@ import org.testcontainers.milvus.MilvusContainer;
 import org.testcontainers.oceanbase.OceanBaseCEContainer;
 import org.testcontainers.utility.DockerLoggerFactory;
 
-import com.google.common.collect.Lists;
 import com.google.gson.Gson;
 import com.google.gson.JsonObject;
 import io.milvus.client.MilvusServiceClient;
@@ -74,7 +75,10 @@ import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 import java.util.Properties;
+import java.util.Random;
 import java.util.concurrent.TimeUnit;
+import java.util.stream.Collectors;
+import java.util.stream.DoubleStream;
 import java.util.stream.Stream;
 
 import static org.awaitility.Awaitility.given;
@@ -127,7 +131,7 @@ public class JdbcOceanBaseMilvusIT extends TestSuiteBase implements TestResource
             };
 
     String driverUrl() {
-        return "https://repo1.maven.org/maven2/com/oceanbase/oceanbase-client/2.4.11/oceanbase-client-2.4.11.jar";
+        return "https://repo1.maven.org/maven2/com/oceanbase/oceanbase-client/2.4.12/oceanbase-client-2.4.12.jar";
     }
 
     @BeforeAll
@@ -263,7 +267,8 @@ public class JdbcOceanBaseMilvusIT extends TestSuiteBase implements TestResource
     @TestTemplate
     public void testMilvusToOceanBase(TestContainer container) throws Exception {
         try {
-            Container.ExecResult execResult = container.executeJob(configFile().get(0));
+            Container.ExecResult execResult =
+                    container.executeJob("/jdbc_milvus_source_and_oceanbase_sink.conf");
             Assertions.assertEquals(0, execResult.getExitCode(), execResult.getStderr());
         } finally {
             clearTable(jdbcCase.getDatabase(), jdbcCase.getSchema(), jdbcCase.getSinkTable());
@@ -274,13 +279,72 @@ public class JdbcOceanBaseMilvusIT extends TestSuiteBase implements TestResource
     public void testFakeToOceanBase(TestContainer container)
             throws IOException, InterruptedException {
         try {
-            Container.ExecResult execResult = container.executeJob(configFile().get(1));
+            Container.ExecResult execResult =
+                    container.executeJob("/jdbc_fake_to_oceanbase_sink.conf");
             Assertions.assertEquals(0, execResult.getExitCode(), execResult.getStderr());
         } finally {
             clearTable(jdbcCase.getDatabase(), jdbcCase.getSchema(), jdbcCase.getSinkTable());
         }
     }
 
+    @TestTemplate
+    public void testOceanBaseToMilvus(TestContainer container) throws Exception {
+        try {
+            initOceanBaseTestData();
+            Container.ExecResult execResult =
+                    container.executeJob("/jdbc_oceanbase_source_and_milvus_sink.conf");
+            Assertions.assertEquals(0, execResult.getExitCode(), execResult.getStderr());
+        } finally {
+            clearTable(jdbcCase.getDatabase(), jdbcCase.getSchema(), jdbcCase.getSinkTable());
+        }
+    }
+
+    private void initOceanBaseTestData() {
+        try (Statement statement = connection.createStatement()) {
+            statement.execute(insertTable());
+            connection.commit();
+        } catch (SQLException e) {
+            try {
+                connection.rollback();
+            } catch (SQLException exception) {
+                throw new SeaTunnelRuntimeException(JdbcITErrorCode.CLEAR_TABLE_FAILED, exception);
+            }
+            throw new SeaTunnelRuntimeException(JdbcITErrorCode.CLEAR_TABLE_FAILED, e);
+        }
+    }
+
+    public String insertTable() {
+        Pair<String[], List<SeaTunnelRow>> testDataSet = initTestData();
+        String[] fieldNames = testDataSet.getKey();
+        String columns =
+                Arrays.stream(fieldNames)
+                        .map(this::quoteIdentifier)
+                        .collect(Collectors.joining(", "));
+        List<Object[]> fields =
+                testDataSet.getValue().stream()
+                        .map(SeaTunnelRow::getFields)
+                        .collect(Collectors.toList());
+
+        StringBuilder sqlBuilder = new StringBuilder();
+        sqlBuilder
+                .append("INSERT INTO ")
+                .append(buildTableInfoWithSchema(OCEANBASE_DATABASE, OCEANBASE_SINK))
+                .append(" (")
+                .append(columns)
+                .append(") VALUES ");
+
+        int valuesCount = fields.size();
+        for (int i = 0; i < valuesCount; i++) {
+            String fieldData = Arrays.toString(fields.get(i));
+            sqlBuilder.append("(").append(fieldData, 1, fieldData.length() - 1).append(")");
+
+            if (i < valuesCount - 1) {
+                sqlBuilder.append(", ");
+            }
+        }
+        return sqlBuilder.toString();
+    }
+
     private void clearTable(String database, String schema, String table) {
         clearTable(database, table);
     }
@@ -322,11 +386,6 @@ public class JdbcOceanBaseMilvusIT extends TestSuiteBase implements TestResource
                 .build();
     }
 
-    List<String> configFile() {
-        return Lists.newArrayList(
-                "/jdbc_milvus_source_and_oceanbase_sink.conf", "/jdbc_fake_to_oceanbase_sink.conf");
-    }
-
     private void initializeJdbcConnection(String jdbcUrl)
             throws SQLException, InstantiationException, IllegalAccessException {
         Driver driver = (Driver) loadDriverClass().newInstance();
@@ -433,4 +492,33 @@ public class JdbcOceanBaseMilvusIT extends TestSuiteBase implements TestResource
             return quoteIdentifier(table);
         }
     }
+
+    private String[] getFieldNames() {
+        return new String[] {
+            "book_id", "book_intro", "book_title",
+        };
+    }
+
+    private Pair<String[], List<SeaTunnelRow>> initTestData() {
+        String[] fieldNames = getFieldNames();
+
+        List<SeaTunnelRow> rows = new ArrayList<>();
+        Random random = new Random();
+        for (int i = 0; i < 100; i++) {
+            SeaTunnelRow row =
+                    new SeaTunnelRow(
+                            new Object[] {
+                                i + 100,
+                                "'"
+                                        + DoubleStream.generate(() -> random.nextDouble() * 10)
+                                                .limit(VECTOR_DIM)
+                                                .mapToObj(num -> String.format("%.4f", num))
+                                                .collect(Collectors.joining(", ", "[", "]"))
+                                        + "'",
+                                "\"" + "test" + i + "\"",
+                            });
+            rows.add(row);
+        }
+        return Pair.of(fieldNames, rows);
+    }
 }
