@@ -19,6 +19,7 @@ package org.apache.seatunnel.e2e.connector.rocketmq;
 
 import org.apache.seatunnel.shade.com.fasterxml.jackson.databind.ObjectMapper;
 import org.apache.seatunnel.shade.com.fasterxml.jackson.databind.node.ObjectNode;
+import org.apache.seatunnel.shade.com.google.common.collect.Lists;
 
 import org.apache.seatunnel.api.table.type.ArrayType;
 import org.apache.seatunnel.api.table.type.BasicType;
@@ -60,7 +61,6 @@ import org.testcontainers.containers.wait.strategy.HostPortWaitStrategy;
 import org.testcontainers.utility.DockerImageName;
 import org.testcontainers.utility.DockerLoggerFactory;
 
-import com.google.common.collect.Lists;
 import lombok.SneakyThrows;
 import lombok.extern.slf4j.Slf4j;
 
@@ -147,6 +147,7 @@ public class RocketMqIT extends TestSuiteBase implements TestResource {
         DefaultSeaTunnelRowSerializer serializer =
                 new DefaultSeaTunnelRowSerializer(
                         "test_topic_source",
+                        null,
                         SEATUNNEL_ROW_TYPE,
                         DEFAULT_FORMAT,
                         DEFAULT_FIELD_DELIMITER);
@@ -183,7 +184,7 @@ public class RocketMqIT extends TestSuiteBase implements TestResource {
         Assertions.assertEquals(0, execResult.getExitCode(), execResult.getStderr());
 
         String topicName = "test_topic";
-        Map<String, String> data = getRocketMqConsumerData(topicName);
+        Map<String, RocketMqConsumerMessage> data = getRocketMqConsumerData(topicName);
         ObjectMapper objectMapper = new ObjectMapper();
         String key = data.keySet().iterator().next();
         ObjectNode objectNode = objectMapper.readValue(key, ObjectNode.class);
@@ -199,7 +200,7 @@ public class RocketMqIT extends TestSuiteBase implements TestResource {
                 container.executeJob("/rocketmq-text-sink_fake_to_rocketmq.conf");
         Assertions.assertEquals(0, execResult.getExitCode(), execResult.getStderr());
         String topicName = "test_text_topic";
-        Map<String, String> data = getRocketMqConsumerData(topicName);
+        Map<String, RocketMqConsumerMessage> data = getRocketMqConsumerData(topicName);
         Assertions.assertEquals(10, data.size());
     }
 
@@ -209,6 +210,7 @@ public class RocketMqIT extends TestSuiteBase implements TestResource {
         DefaultSeaTunnelRowSerializer serializer =
                 new DefaultSeaTunnelRowSerializer(
                         "test_topic_text",
+                        null,
                         SEATUNNEL_ROW_TYPE,
                         SchemaFormat.TEXT,
                         DEFAULT_FIELD_DELIMITER);
@@ -228,6 +230,7 @@ public class RocketMqIT extends TestSuiteBase implements TestResource {
         DefaultSeaTunnelRowSerializer serializer =
                 new DefaultSeaTunnelRowSerializer(
                         "test_topic_text_offset_check",
+                        null,
                         SEATUNNEL_ROW_TYPE,
                         SchemaFormat.TEXT,
                         DEFAULT_FIELD_DELIMITER);
@@ -245,6 +248,7 @@ public class RocketMqIT extends TestSuiteBase implements TestResource {
         DefaultSeaTunnelRowSerializer serializer =
                 new DefaultSeaTunnelRowSerializer(
                         "test_topic_json",
+                        null,
                         SEATUNNEL_ROW_TYPE,
                         DEFAULT_FORMAT,
                         DEFAULT_FIELD_DELIMITER);
@@ -292,6 +296,7 @@ public class RocketMqIT extends TestSuiteBase implements TestResource {
         DefaultSeaTunnelRowSerializer serializer =
                 new DefaultSeaTunnelRowSerializer(
                         "test_topic_group",
+                        null,
                         SEATUNNEL_ROW_TYPE,
                         DEFAULT_FORMAT,
                         DEFAULT_FIELD_DELIMITER);
@@ -299,6 +304,25 @@ public class RocketMqIT extends TestSuiteBase implements TestResource {
         testRocketMqGroupOffsetsToConsole(container);
     }
 
+    @TestTemplate
+    public void testSinkRocketMqMessageTag(TestContainer container)
+            throws IOException, InterruptedException {
+        Container.ExecResult execResult =
+                container.executeJob("/rocketmq-sink_fake_to_rocketmq_message_tag.conf");
+        Assertions.assertEquals(0, execResult.getExitCode(), execResult.getStderr());
+
+        String topicName = "test_topic_message_tag";
+        String tag = "test_tag";
+        Map<String, RocketMqConsumerMessage> data = getRocketMqConsumerData(topicName);
+        ObjectMapper objectMapper = new ObjectMapper();
+        String key = data.keySet().iterator().next();
+        ObjectNode objectNode = objectMapper.readValue(key, ObjectNode.class);
+        Assertions.assertTrue(objectNode.has("c_map"));
+        Assertions.assertTrue(objectNode.has("c_string"));
+        Assertions.assertEquals(10, data.size());
+        Assertions.assertEquals(tag, data.get(key).getTag());
+    }
+
     public void testRocketMqGroupOffsetsToConsole(TestContainer container)
             throws IOException, InterruptedException {
         Container.ExecResult execResult =
@@ -334,8 +358,8 @@ public class RocketMqIT extends TestSuiteBase implements TestResource {
         }
     }
 
-    private Map<String, String> getRocketMqConsumerData(String topicName) {
-        Map<String, String> data = new HashMap<>();
+    private Map<String, RocketMqConsumerMessage> getRocketMqConsumerData(String topicName) {
+        Map<String, RocketMqConsumerMessage> data = new HashMap<>();
         try {
             DefaultLitePullConsumer consumer =
                     RocketMqAdminUtil.initDefaultLitePullConsumer(newConfiguration(), false);
@@ -373,9 +397,11 @@ public class RocketMqIT extends TestSuiteBase implements TestResource {
                     break;
                 }
                 for (MessageExt message : messages) {
-                    data.put(
-                            message.getKeys(),
-                            new String(message.getBody(), StandardCharsets.UTF_8));
+                    RocketMqConsumerMessage consumerMessage =
+                            new RocketMqConsumerMessage(
+                                    new String(message.getBody(), StandardCharsets.UTF_8),
+                                    message.getTags());
+                    data.put(message.getKeys(), consumerMessage);
                     consumer.getOffsetStore()
                             .updateConsumeOffsetToBroker(
                                     new MessageQueue(
