@@ -22,10 +22,14 @@ import org.apache.seatunnel.engine.common.config.server.CheckpointStorageConfig;
 import org.apache.seatunnel.engine.common.config.server.ConnectorJarHAStorageConfig;
 import org.apache.seatunnel.engine.common.config.server.ConnectorJarStorageConfig;
 import org.apache.seatunnel.engine.common.config.server.ConnectorJarStorageMode;
+import org.apache.seatunnel.engine.common.config.server.CoordinatorServiceConfig;
+import org.apache.seatunnel.engine.common.config.server.HttpConfig;
 import org.apache.seatunnel.engine.common.config.server.QueueType;
+import org.apache.seatunnel.engine.common.config.server.ScheduleStrategy;
 import org.apache.seatunnel.engine.common.config.server.ServerConfigOptions;
 import org.apache.seatunnel.engine.common.config.server.SlotServiceConfig;
 import org.apache.seatunnel.engine.common.config.server.TelemetryConfig;
+import org.apache.seatunnel.engine.common.config.server.TelemetryLogsConfig;
 import org.apache.seatunnel.engine.common.config.server.TelemetryMetricConfig;
 import org.apache.seatunnel.engine.common.config.server.ThreadShareMode;
 
@@ -103,6 +107,25 @@ public class YamlSeaTunnelDomConfigProcessor extends AbstractDomConfigProcessor
         return slotServiceConfig;
     }
 
+    private CoordinatorServiceConfig parseCoordinatorServiceConfig(Node coordinatorServiceNode) {
+        CoordinatorServiceConfig coordinatorServiceConfig = new CoordinatorServiceConfig();
+        for (Node node : childElements(coordinatorServiceNode)) {
+            String name = cleanNodeName(node);
+            if (ServerConfigOptions.MAX_THREAD_NUM.key().equals(name)) {
+                coordinatorServiceConfig.setMaxThreadNum(
+                        getIntegerValue(
+                                ServerConfigOptions.MAX_THREAD_NUM.key(), getTextContent(node)));
+            } else if (ServerConfigOptions.CORE_THREAD_NUM.key().equals(name)) {
+                coordinatorServiceConfig.setCoreThreadNum(
+                        getIntegerValue(
+                                ServerConfigOptions.CORE_THREAD_NUM.key(), getTextContent(node)));
+            } else {
+                LOGGER.warning("Unrecognized element: " + name);
+            }
+        }
+        return coordinatorServiceConfig;
+    }
+
     private void parseEngineConfig(Node engineNode, SeaTunnelConfig config) {
         final EngineConfig engineConfig = config.getEngineConfig();
         for (Node node : childElements(engineNode)) {
@@ -169,10 +192,23 @@ public class YamlSeaTunnelDomConfigProcessor extends AbstractDomConfigProcessor
                 }
             } else if (ServerConfigOptions.TELEMETRY.key().equals(name)) {
                 engineConfig.setTelemetryConfig(parseTelemetryConfig(node));
+            } else if (ServerConfigOptions.JOB_SCHEDULE_STRATEGY.key().equals(name)) {
+                engineConfig.setScheduleStrategy(
+                        ScheduleStrategy.valueOf(getTextContent(node).toUpperCase(Locale.ROOT)));
+            } else if (ServerConfigOptions.HTTP.key().equals(name)) {
+                engineConfig.setHttpConfig(parseHttpConfig(node));
+            } else if (ServerConfigOptions.COORDINATOR_SERVICE.key().equals(name)) {
+                engineConfig.setCoordinatorServiceConfig(parseCoordinatorServiceConfig(node));
             } else {
                 LOGGER.warning("Unrecognized element: " + name);
             }
         }
+
+        if (engineConfig.getSlotServiceConfig().isDynamicSlot()) {
+            // If dynamic slot is enabled, the schedule strategy must be REJECT
+            LOGGER.info("Dynamic slot is enabled, the schedule strategy is set to REJECT");
+            engineConfig.setScheduleStrategy(ScheduleStrategy.REJECT);
+        }
     }
 
     private CheckpointConfig parseCheckpointConfig(Node checkpointNode) {
@@ -317,17 +353,19 @@ public class YamlSeaTunnelDomConfigProcessor extends AbstractDomConfigProcessor
     }
 
     private TelemetryConfig parseTelemetryConfig(Node telemetryNode) {
-        TelemetryConfig metricConfig = new TelemetryConfig();
+        TelemetryConfig telemetryConfig = new TelemetryConfig();
         for (Node node : childElements(telemetryNode)) {
             String name = cleanNodeName(node);
             if (ServerConfigOptions.TELEMETRY_METRIC.key().equals(name)) {
-                metricConfig.setMetric(parseTelemetryMetricConfig(node));
+                telemetryConfig.setMetric(parseTelemetryMetricConfig(node));
+            } else if (ServerConfigOptions.TELEMETRY_LOGS.key().equals(name)) {
+                telemetryConfig.setLogs(parseTelemetryLogsConfig(node));
             } else {
                 LOGGER.warning("Unrecognized element: " + name);
             }
         }
 
-        return metricConfig;
+        return telemetryConfig;
     }
 
     private TelemetryMetricConfig parseTelemetryMetricConfig(Node metricNode) {
@@ -343,4 +381,42 @@ public class YamlSeaTunnelDomConfigProcessor extends AbstractDomConfigProcessor
 
         return metricConfig;
     }
+
+    private TelemetryLogsConfig parseTelemetryLogsConfig(Node logsNode) {
+        TelemetryLogsConfig logsConfig = new TelemetryLogsConfig();
+        for (Node node : childElements(logsNode)) {
+            String name = cleanNodeName(node);
+            if (ServerConfigOptions.TELEMETRY_LOGS_SCHEDULED_DELETION_ENABLE.key().equals(name)) {
+                logsConfig.setEnabled(getBooleanValue(getTextContent(node)));
+            } else {
+                LOGGER.warning("Unrecognized element: " + name);
+            }
+        }
+
+        return logsConfig;
+    }
+
+    private HttpConfig parseHttpConfig(Node httpNode) {
+        HttpConfig httpConfig = new HttpConfig();
+        for (Node node : childElements(httpNode)) {
+            String name = cleanNodeName(node);
+            if (ServerConfigOptions.PORT.key().equals(name)) {
+                httpConfig.setPort(
+                        getIntegerValue(ServerConfigOptions.PORT.key(), getTextContent(node)));
+            } else if (ServerConfigOptions.CONTEXT_PATH.key().equals(name)) {
+                httpConfig.setContextPath(getTextContent(node));
+            } else if (ServerConfigOptions.ENABLE_HTTP.key().equals(name)) {
+                httpConfig.setEnabled(getBooleanValue(getTextContent(node)));
+            } else if (ServerConfigOptions.ENABLE_DYNAMIC_PORT.key().equals(name)) {
+                httpConfig.setEnableDynamicPort(getBooleanValue(getTextContent(node)));
+            } else if (ServerConfigOptions.PORT_RANGE.key().equals(name)) {
+                httpConfig.setPortRange(
+                        getIntegerValue(
+                                ServerConfigOptions.PORT_RANGE.key(), getTextContent(node)));
+            } else {
+                LOGGER.warning("Unrecognized element: " + name);
+            }
+        }
+        return httpConfig;
+    }
 }
