@@ -25,7 +25,13 @@ public enum TransformCommonErrorCode implements SeaTunnelErrorCode {
             "The input field '<field>' of '<transform>' transform not found in upstream schema"),
     INPUT_FIELDS_NOT_FOUND(
             "TRANSFORM_COMMON-02",
-            "The input fields '<fields>' of '<transform>' transform not found in upstream schema");
+            "The input fields '<fields>' of '<transform>' transform not found in upstream schema"),
+    METADATA_FIELDS_NOT_FOUND(
+            "TRANSFORM_COMMON-03",
+            "The metadata fields '<field>' of '<transform>' transform not found "),
+    METADATA_MAPPING_FIELD_EXISTS(
+            "TRANSFORM_COMMON-04",
+            "The metadata mapping field '<field>' of '<transform>' transform already exists in upstream schema");
 
     private final String code;
     private final String description;
