@@ -21,9 +21,9 @@ import org.apache.seatunnel.api.table.catalog.CatalogTable;
 import org.apache.seatunnel.api.table.catalog.Column;
 import org.apache.seatunnel.api.table.catalog.PhysicalColumn;
 import org.apache.seatunnel.api.table.type.BasicType;
+import org.apache.seatunnel.api.table.type.SeaTunnelRowAccessor;
 import org.apache.seatunnel.api.table.type.SeaTunnelRowType;
 import org.apache.seatunnel.transform.common.MultipleFieldOutputTransform;
-import org.apache.seatunnel.transform.common.SeaTunnelRowAccessor;
 import org.apache.seatunnel.transform.exception.TransformCommonError;
 
 import lombok.NonNull;
@@ -31,6 +31,7 @@ import lombok.NonNull;
 import java.util.Arrays;
 
 public class SplitTransform extends MultipleFieldOutputTransform {
+    public static String PLUGIN_NAME = "Split";
     private final SplitTransformConfig splitTransformConfig;
     private final int splitFieldIndex;
 
